@@ -56,7 +56,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
  *
  * This is the interface implemented by the rhythmbox playback backends.
  * It allows the caller to control playback (open, play, pause, close), 
- * seek (set_time), control volume (get_volume, set_volume, set_replaygain)
+ * seek (set_time), control volume (get_volume, set_volume)
  * and receive playback state information (get_time, various signals).
  *
  * The playback interface allows for multiple streams to be playing (or at
@@ -92,8 +92,11 @@ rb_player_interface_init (RBPlayerIface *iface)
 	 * RBPlayer::eos:
 	 * @player: the #RBPlayer
 	 * @stream_data: the data associated with the stream that finished
+	 * @early: if %TRUE, the EOS notification should only be used for track changes.
 	 *
-	 * The 'eos' signal is emitted when a stream finishes.
+	 * The 'eos' signal is emitted when a stream finishes, or in some cases, when it
+	 * is about to finish (with @early set to %TRUE) to allow for a new track to be
+	 * played immediately afterwards.
 	 **/
 	signals[EOS] =
 		g_signal_new ("eos",
@@ -101,9 +104,9 @@ rb_player_interface_init (RBPlayerIface *iface)
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
 			      G_STRUCT_OFFSET (RBPlayerIface, eos),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
+			      rb_marshal_VOID__POINTER_BOOLEAN,
 			      G_TYPE_NONE,
-			      1, G_TYPE_POINTER);
+			      2, G_TYPE_POINTER, G_TYPE_BOOLEAN);
 
 	/**
 	 * RBPlayer::info:
@@ -325,6 +328,8 @@ rb_player_open (RBPlayer *player, const char *uri, gpointer stream_data, GDestro
  * rb_player_opened:
  * @player: 	a #RBPlayer
  *
+ * Determines whether a stream has been prepared for playback.
+ *
  * Return value: TRUE if a stream is prepared for playback
  */
 gboolean
@@ -414,8 +419,10 @@ rb_player_pause (RBPlayer *player)
  * rb_player_playing:
  * @player:	a #RBPlayer.
  *
- * Return value: TRUE if a stream is currently being played (not paused
- *  or being faded out).
+ * Determines whether the player is currently playing a stream.
+ * A stream is playing if it's not paused or being faded out.
+ *
+ * Return value: TRUE if playing
  */
 gboolean
 rb_player_playing (RBPlayer *player)
@@ -446,6 +453,8 @@ rb_player_set_volume (RBPlayer *player, float volume)
  * rb_player_get_volume:
  * @player:	a #RBPlayer
  *
+ * Returns the current volume level, between 0.0 and 1.0.
+ *
  * Return value: current output volume level
  */
 float
@@ -456,32 +465,12 @@ rb_player_get_volume (RBPlayer *player)
 	return iface->get_volume (player);
 }
 
-/**
- * rb_player_set_replaygain:
- * @player:	a #RBPlayer
- * @uri:	URI of stream to adjust
- * @track_gain: ReplayGain track gain level
- * @track_peak: ReplayGain track peak level
- * @album_gain: ReplayGain album gain level
- * @album_peak: ReplayGain album peak level
- *
- * Sets ReplayGain values for a stream
- */
-void
-rb_player_set_replaygain (RBPlayer *player,
-			  const char *uri,
-			  double track_gain, double track_peak,
-			  double album_gain, double album_peak)
-{
-	RBPlayerIface *iface = RB_PLAYER_GET_IFACE (player);
-
-	iface->set_replaygain (player, uri, track_gain, track_peak, album_gain, album_peak);
-}
-
 /**
  * rb_player_seekable:
  * @player:	a #RBPlayer
  *
+ * Determines whether seeking is supported for the current stream.
+ *
  * Return value: TRUE if the current stream is seekable
  */
 gboolean
@@ -513,8 +502,9 @@ rb_player_set_time (RBPlayer *player, gint64 newtime)
  * rb_player_get_time:
  * @player:	a #RBPlayer
  *
- * Return value: the current playback position in the current stream
- *  in nanoseconds.
+ * Returns the current playback for the current stream in nanoseconds.
+ *
+ * Return value: playback position
  */
 gint64
 rb_player_get_time (RBPlayer *player)
@@ -528,8 +518,9 @@ rb_player_get_time (RBPlayer *player)
  * rb_player_multiple_open:
  * @player:	a #RBPlayer
  *
- * Return value: TRUE if the player supports multiple open streams
- * 		(not necessarily multiple playing streams, though)
+ * Determines whether the player supports multiple open streams.
+ *
+ * Return value: TRUE if multiple open is supported
  */
 gboolean
 rb_player_multiple_open (RBPlayer *player)
@@ -565,14 +556,15 @@ rb_player_new (gboolean want_crossfade, GError **error)
  * _rb_player_emit_eos:
  * @player: a #RBPlayer implementation
  * @stream_data: data associated with the stream
+ * @early: whether this is an early EOS notification
  *
  * Emits the 'eos' signal for a stream.  To be used by
  * implementations only.
  */
 void
-_rb_player_emit_eos (RBPlayer *player, gpointer stream_data)
+_rb_player_emit_eos (RBPlayer *player, gpointer stream_data, gboolean early)
 {
-	g_signal_emit (player, signals[EOS], 0, stream_data);
+	g_signal_emit (player, signals[EOS], 0, stream_data, early);
 }
 
 /**
