@@ -126,7 +126,15 @@ extern void rb_marshal_BOXED__OBJECT (GClosure     *closure,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
 
-/* VOID:BOXED,BOXED (./rb-marshal.list:16) */
+/* BOXED:STRING (./rb-marshal.list:16) */
+extern void rb_marshal_BOXED__STRING (GClosure     *closure,
+                                      GValue       *return_value,
+                                      guint         n_param_values,
+                                      const GValue *param_values,
+                                      gpointer      invocation_hint,
+                                      gpointer      marshal_data);
+
+/* VOID:BOXED,BOXED (./rb-marshal.list:17) */
 extern void rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -134,7 +142,7 @@ extern void rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:17) */
+/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:18) */
 extern void rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -142,7 +150,7 @@ extern void rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:BOXED,OBJECT (./rb-marshal.list:18) */
+/* VOID:BOXED,OBJECT (./rb-marshal.list:19) */
 extern void rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -150,7 +158,7 @@ extern void rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:BOXED,POINTER (./rb-marshal.list:19) */
+/* VOID:BOXED,POINTER (./rb-marshal.list:20) */
 extern void rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -158,7 +166,7 @@ extern void rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:20) */
+/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:21) */
 extern void rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -166,7 +174,7 @@ extern void rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:BOXED,ULONG (./rb-marshal.list:21) */
+/* VOID:BOXED,ULONG (./rb-marshal.list:22) */
 extern void rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -174,7 +182,7 @@ extern void rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:DOUBLE,LONG (./rb-marshal.list:22) */
+/* VOID:DOUBLE,LONG (./rb-marshal.list:23) */
 extern void rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -182,7 +190,7 @@ extern void rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:UINT64 (./rb-marshal.list:23) */
+/* VOID:UINT64 (./rb-marshal.list:24) */
 extern void rb_marshal_VOID__UINT64 (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -190,7 +198,7 @@ extern void rb_marshal_VOID__UINT64 (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* VOID:INT,INT (./rb-marshal.list:24) */
+/* VOID:INT,INT (./rb-marshal.list:25) */
 extern void rb_marshal_VOID__INT_INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -198,7 +206,7 @@ extern void rb_marshal_VOID__INT_INT (GClosure     *closure,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
 
-/* VOID:INT,INT,DOUBLE (./rb-marshal.list:25) */
+/* VOID:INT,INT,DOUBLE (./rb-marshal.list:26) */
 extern void rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -206,7 +214,7 @@ extern void rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:INT64 (./rb-marshal.list:26) */
+/* VOID:INT64 (./rb-marshal.list:27) */
 extern void rb_marshal_VOID__INT64 (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
@@ -214,7 +222,7 @@ extern void rb_marshal_VOID__INT64 (GClosure     *closure,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,INT (./rb-marshal.list:27) */
+/* VOID:OBJECT,INT,INT (./rb-marshal.list:28) */
 extern void rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -222,7 +230,7 @@ extern void rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:28) */
+/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:29) */
 extern void rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -230,7 +238,7 @@ extern void rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:29) */
+/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:30) */
 extern void rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -238,7 +246,7 @@ extern void rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:POINTER,BOOLEAN (./rb-marshal.list:30) */
+/* VOID:POINTER,BOOLEAN (./rb-marshal.list:31) */
 extern void rb_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -246,7 +254,7 @@ extern void rb_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:POINTER,INT (./rb-marshal.list:31) */
+/* VOID:POINTER,INT (./rb-marshal.list:32) */
 extern void rb_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -254,7 +262,7 @@ extern void rb_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:POINTER,INT64,INT64 (./rb-marshal.list:32) */
+/* VOID:POINTER,INT64,INT64 (./rb-marshal.list:33) */
 extern void rb_marshal_VOID__POINTER_INT64_INT64 (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -262,7 +270,7 @@ extern void rb_marshal_VOID__POINTER_INT64_INT64 (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:POINTER,INT,POINTER (./rb-marshal.list:33) */
+/* VOID:POINTER,INT,POINTER (./rb-marshal.list:34) */
 extern void rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -270,7 +278,7 @@ extern void rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:POINTER,LONG,LONG (./rb-marshal.list:34) */
+/* VOID:POINTER,LONG,LONG (./rb-marshal.list:35) */
 extern void rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -278,7 +286,7 @@ extern void rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:POINTER,OBJECT (./rb-marshal.list:35) */
+/* VOID:POINTER,OBJECT (./rb-marshal.list:36) */
 extern void rb_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -286,7 +294,7 @@ extern void rb_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (./rb-marshal.list:36) */
+/* VOID:POINTER,POINTER (./rb-marshal.list:37) */
 extern void rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -294,7 +302,7 @@ extern void rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER,POINTER (./rb-marshal.list:37) */
+/* VOID:POINTER,POINTER,POINTER (./rb-marshal.list:38) */
 extern void rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -302,7 +310,7 @@ extern void rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* VOID:POINTER,UINT (./rb-marshal.list:38) */
+/* VOID:POINTER,UINT (./rb-marshal.list:39) */
 extern void rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -310,7 +318,7 @@ extern void rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:POINTER,ULONG (./rb-marshal.list:39) */
+/* VOID:POINTER,ULONG (./rb-marshal.list:40) */
 extern void rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -318,7 +326,7 @@ extern void rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:STRING,DOUBLE (./rb-marshal.list:40) */
+/* VOID:STRING,DOUBLE (./rb-marshal.list:41) */
 extern void rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -326,7 +334,7 @@ extern void rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:STRING,INT (./rb-marshal.list:41) */
+/* VOID:STRING,INT (./rb-marshal.list:42) */
 extern void rb_marshal_VOID__STRING_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -334,7 +342,7 @@ extern void rb_marshal_VOID__STRING_INT (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* VOID:STRING,OBJECT (./rb-marshal.list:42) */
+/* VOID:STRING,OBJECT (./rb-marshal.list:43) */
 extern void rb_marshal_VOID__STRING_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -342,7 +350,7 @@ extern void rb_marshal_VOID__STRING_OBJECT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:STRING,POINTER (./rb-marshal.list:43) */
+/* VOID:STRING,POINTER (./rb-marshal.list:44) */
 extern void rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -350,7 +358,7 @@ extern void rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING,STRING (./rb-marshal.list:44) */
+/* VOID:STRING,STRING (./rb-marshal.list:45) */
 extern void rb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -358,7 +366,7 @@ extern void rb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:STRING,STRING,OBJECT (./rb-marshal.list:45) */
+/* VOID:STRING,STRING,OBJECT (./rb-marshal.list:46) */
 extern void rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -366,7 +374,7 @@ extern void rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:STRING,STRING,STRING (./rb-marshal.list:46) */
+/* VOID:STRING,STRING,STRING (./rb-marshal.list:47) */
 extern void rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -374,7 +382,7 @@ extern void rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:47) */
+/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:48) */
 extern void rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -382,7 +390,7 @@ extern void rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *cl
                                                                 gpointer      invocation_hint,
                                                                 gpointer      marshal_data);
 
-/* VOID:UINT,STRING,STRING,OBJECT,BOOLEAN (./rb-marshal.list:48) */
+/* VOID:UINT,STRING,STRING,OBJECT,BOOLEAN (./rb-marshal.list:49) */
 extern void rb_marshal_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -390,7 +398,7 @@ extern void rb_marshal_VOID__UINT_STRING_STRING_OBJECT_BOOLEAN (GClosure     *cl
                                                                 gpointer      invocation_hint,
                                                                 gpointer      marshal_data);
 
-/* VOID:ULONG,FLOAT (./rb-marshal.list:49) */
+/* VOID:ULONG,FLOAT (./rb-marshal.list:50) */
 extern void rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -398,7 +406,7 @@ extern void rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:50) */
+/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:51) */
 extern void rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -406,7 +414,7 @@ extern void rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:51) */
+/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:52) */
 extern void rb_marshal_VOID__STRING_STRING_POINTER_POINTER (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
