@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of totally random functions that didn't fit elsewhere
  *
  *  Copyright (C) 2003 Colin Walters <walters@verbum.org>
  *
@@ -9,7 +7,7 @@
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -27,6 +25,16 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  */
+
+/**
+ * SECTION:rb-util
+ * @short_description: assorted utility functions
+ *
+ * This is a dumping ground for utility functions that may or may not
+ * be generally useful in Rhythmbox or elsewhere.  Things end up here
+ * if they're clever or if they're used all over the place.
+ */
+
 #include "config.h"
 
 #include <string.h>
@@ -34,34 +42,65 @@
 #include <stdlib.h>
 
 #include <gtk/gtk.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <glib/gi18n.h>
 #include <gobject/gvaluecollector.h>
+#include <gio/gio.h>
 
 #include "rb-util.h"
 #include "rb-debug.h"
 
 static GPrivate * private_is_primary_thread;
 
+/**
+ * rb_true_function:
+ * @dummy: unused
+ *
+ * Just returns %TRUE, useful as a callback function.
+ *
+ * Return value: %TRUE
+ */
 gboolean
 rb_true_function (gpointer dummy)
 {
 	return TRUE;
 }
 
+/**
+ * rb_false_function:
+ * @dummy: unused
+ *
+ * Just returns %FALSE, useful as a callback function.
+ *
+ * Return value: %FALSE
+ */
 gboolean
 rb_false_function (gpointer dummy)
 {
 	return FALSE;
 }
 
+/**
+ * rb_null_function:
+ * @dummy: unused
+ *
+ * Just returns NULL.  Useful as a callback function.
+ *
+ * Return value: NULL
+ */
 gpointer
 rb_null_function (gpointer dummy)
 {
 	return NULL;
 }
 
+/**
+ * rb_copy_function:
+ * @data: generic argument
+ *
+ * Just returns its first argument.  Useful as a callback function.
+ *
+ * Return value: @data
+ */
 gpointer
 rb_copy_function (gpointer data)
 {
@@ -69,6 +108,17 @@ rb_copy_function (gpointer data)
 }
 
 
+/**
+ * rb_gvalue_compare:
+ * @a: left hand side
+ * @b: right hand size
+ *
+ * Compares @a and @b for sorting.  @a and @b must contain the same value
+ * type for the comparison to be valid.  Comparisons for some value types
+ * are not particularly useful.
+ *
+ * Return value: -1 if @a < @b, 0 if @a == @b, 1 if @a > @b
+ */
 int
 rb_gvalue_compare (GValue *a, GValue *b)
 {
@@ -210,6 +260,15 @@ rb_gvalue_compare (GValue *a, GValue *b)
 	return retval;
 }
 
+/**
+ * rb_compare_gtimeval:
+ * @a: left hand side
+ * @b: right hand size
+ *
+ * Compares two #GTimeval structures for sorting.
+ *
+ * Return value: -1 if @a < @b, 0 if @a == @b, 1 if @a > @b
+ */
 int
 rb_compare_gtimeval (GTimeVal *a, GTimeVal *b)
 {
@@ -225,6 +284,7 @@ rb_compare_gtimeval (GTimeVal *a, GTimeVal *b)
 		return -1;
 }
 
+/* this is obsoleted by g_strcmp0, don't use it */
 int
 rb_safe_strcmp (const char *a,
                 const char *b)
@@ -269,13 +329,19 @@ totem_pixbuf_mirror (GdkPixbuf *pixbuf)
 
 
 
-/* Same as gtk_image_new_from_stock except that it mirrors the icons for RTL 
- * languages
+/**
+ * rb_image_new_from_stock:
+ * @stock_id: stock image id
+ * @size: requested icon size
+ *
+ * Same as @gtk_image_new_from_stock except that it mirrors the icons for RTL
+ * languages.
+ *
+ * Return value: a #GtkImage of the requested stock item
  */
 GtkWidget *
 rb_image_new_from_stock (const gchar *stock_id, GtkIconSize size)
 {
-
 	if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_LTR) {
 		return gtk_image_new_from_stock (stock_id, size);
 	} else {
@@ -295,14 +361,14 @@ rb_image_new_from_stock (const gchar *stock_id, GtkIconSize size)
 		
 		
 		mirror = gdk_pixbuf_copy (pixbuf);
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (pixbuf);
 
 		if (!mirror)
 			return NULL;
 
 		totem_pixbuf_mirror (mirror);
 		gtk_image_set_from_pixbuf (GTK_IMAGE (image), mirror);
-		gdk_pixbuf_unref (mirror);
+		g_object_unref (mirror);
 
 		return image;
 	}
@@ -310,6 +376,14 @@ rb_image_new_from_stock (const gchar *stock_id, GtkIconSize size)
 	return NULL;
 }
 
+/**
+ * rb_gtk_action_popup_menu:
+ * @uimanager: a #GtkUIManager
+ * @path: UI path for the popup to display
+ *
+ * Simple shortcut for getting a popup menu from a #GtkUIManager and
+ * displaying it.
+ */
 void
 rb_gtk_action_popup_menu (GtkUIManager *uimanager, const char *path)
 {
@@ -319,140 +393,18 @@ rb_gtk_action_popup_menu (GtkUIManager *uimanager, const char *path)
 	if (menu == NULL) {
 		g_warning ("Couldn't get menu widget for %s", path);
 	} else {
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 
-			gtk_get_current_event_time ());
+		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 
+				gtk_get_current_event_time ());
 	}
 }
 
-static GList *
-get_mount_points (void)
-{
-	GnomeVFSVolumeMonitor *monitor;
-	GList *volumes;
-	GList *it;
-	GList *mount_points = NULL;
-
-	monitor = gnome_vfs_get_volume_monitor ();
-	/* FIXME: should also get the list of connected drivers (network
-	 * shares I assume)
-	 */
-	volumes = gnome_vfs_volume_monitor_get_mounted_volumes (monitor);
-
-	for (it = volumes; it != NULL; it = it->next) {
-		gchar *uri;
-		GnomeVFSVolume *volume;
-
-		volume = GNOME_VFS_VOLUME (it->data);
-		uri = gnome_vfs_volume_get_activation_uri (volume);
-		g_assert (uri != NULL);
-		mount_points = g_list_prepend (mount_points, uri);
-	}
-
-	g_list_foreach (volumes, (GFunc)gnome_vfs_volume_unref, NULL);
-	g_list_free (volumes);
-
-	return mount_points;
-}
-
-
-gchar *
-rb_uri_get_mount_point (const char *uri)
-{
-	GList *mount_points = get_mount_points ();
-	GList *it;
-	gchar *mount_point = NULL;
-
-	for (it = mount_points; it != NULL; it = it->next) {
-		if (g_str_has_prefix (uri, it->data)) {
-			if ((mount_point == NULL) || (strlen (mount_point) < strlen (it->data))) {
-				g_free (mount_point);
-				mount_point = g_strdup (it->data);
-			}
-		}
-	}
-	g_list_foreach (mount_points, (GFunc)g_free, NULL);
-	g_list_free (mount_points);
-
-	return mount_point;
-}
-
-gchar *
-rb_uri_get_filesystem_type(const char *uri)
-{
-	GnomeVFSVolume *volume = NULL;
-	GnomeVFSVolumeMonitor *monitor = NULL;
-	gchar *mount_point_uri = NULL, *mount_point_path = NULL;
-	gchar *fstype = NULL;
-	GError *error = NULL;
-	
-	g_return_val_if_fail(uri != NULL, NULL);
-
-	monitor = gnome_vfs_get_volume_monitor ();
-	if (monitor == NULL) {
-		goto error;
-	}
-
-	mount_point_uri = rb_uri_get_mount_point(uri);
-	if (mount_point_uri == NULL) {
-		goto error;
-	}
-	
-	mount_point_path = g_filename_from_uri(mount_point_uri, NULL, &error);
-	if (error) {
-		g_warning("%s", error->message);
-		g_error_free(error);
-		goto error;
-	}
-
-	volume = gnome_vfs_volume_monitor_get_volume_for_path(monitor, mount_point_path);
-	if (volume  == NULL) {
- 		goto error;
-	}
-	g_free(mount_point_path);
-	g_free(mount_point_uri);
-
-	fstype = gnome_vfs_volume_get_filesystem_type(volume);
-	
-	gnome_vfs_volume_unref(volume);
-	
-	return fstype;
-
- error:
-	if (volume != NULL) {
-		gnome_vfs_volume_unref(volume);
-	}
-	g_free(mount_point_path);
-	g_free(mount_point_uri);
-	return NULL;
-}
-
-gboolean
-rb_uri_is_mounted (const char *uri)
-{
-	GList *mount_points = get_mount_points ();
-	GList *it;
-	gboolean found = FALSE;
-
-	if ((uri == NULL) || (*uri == '\0')) {
-		return TRUE;
-	}
-
-	for (it = mount_points; it != NULL; it = it->next) {
-		if (strcmp (it->data, uri) == 0) {
-			found = TRUE;
-			break;
-		}
-	}
-	g_list_foreach (mount_points, (GFunc)g_free, NULL);
-	g_list_free (mount_points);
-
-/*	if (found == FALSE) {
-		g_print ("%s not mounted\n", uri);
-		}*/
-
-	return found;
-}
-
+/**
+ * rb_is_main_thread:
+ *
+ * Checks if currently executing on the main thread.
+ *
+ * Return value: %TRUE if on the main thread
+ */
 gboolean
 rb_is_main_thread (void)
 {
@@ -487,13 +439,25 @@ _threads_leave (void)
 }
 
 
+/**
+ * rb_assert_locked:
+ * @mutex: a #GMutex
+ *
+ * Asserts that @mutex is currently locked.  Does not work with all
+ * mutex implementations.
+ */
 void
-rb_assert_locked (GMutex *m)
+rb_assert_locked (GMutex *mutex)
 {
 	if (!mutex_recurses)
-		g_assert (!g_mutex_trylock (m));
+		g_assert (!g_mutex_trylock (mutex));
 }
 
+/**
+ * rb_threads_init:
+ *
+ * Initializes various thread helpers.  Must be called on startup.
+ */
 void
 rb_threads_init (void)
 {
@@ -518,9 +482,17 @@ rb_threads_init (void)
 	rb_debug ("GMutex %s recursive", mutex_recurses ? "is" : "isn't");
 
 	/* purge useless thread-pool threads occasionally */
-	g_timeout_add (30 * 1000, purge_useless_threads, NULL);
+	g_timeout_add_seconds (30, purge_useless_threads, NULL);
 }
 
+/**
+ * rb_string_split_words:
+ * @string: the string to split
+ *
+ * Splits @string on word boundaries using Unicode character definitions.
+ *
+ * Return value: NULL-terminated array of strings, must be freed by caller (see @g_strfreev)
+ */
 gchar **
 rb_string_split_words (const gchar *string)
 {
@@ -626,6 +598,15 @@ rb_string_split_words (const gchar *string)
 	return ret;
 }
 
+/**
+ * rb_search_fold:
+ * @original: the string to fold
+ *
+ * Returns a case-folded and punctuation-stripped version of @original, useful
+ * for performing text searches.
+ *
+ * Return value: case-folded string, must be freed by caller.
+ */
 gchar*
 rb_search_fold (const char *original)
 {
@@ -692,6 +673,15 @@ rb_search_fold (const char *original)
 	return g_string_free (string, FALSE);
 }
 
+/**
+ * rb_make_duration_string:
+ * @duration: duration in seconds
+ *
+ * Constructs a string describing the specified duration.  The string
+ * describes hours, minutes, and seconds, and its format is localised.
+ *
+ * Return value: duration string, must be freed by caller.
+ */
 char *
 rb_make_duration_string (guint duration)
 {
@@ -712,6 +702,18 @@ rb_make_duration_string (guint duration)
 	return str;
 }
 
+/**
+ * rb_make_elapsed_time_string:
+ * @elapsed: elapsed time (in seconds)
+ * @duration: duration (in seconds)
+ * @show_remaining: if %TRUE, show the remaining time, otherwise show elapsed time
+ *
+ * Constructs a string describing a playback position.  The string describes hours,
+ * minutes, and seconds, and its format is localised.  The string can describe either
+ * the elapsed time or the time remaining.
+ *
+ * Return value: elapsed/remaining time string, must be freed by caller
+ */
 char *
 rb_make_elapsed_time_string (guint elapsed, guint duration, gboolean show_remaining)
 {
@@ -761,6 +763,16 @@ rb_make_elapsed_time_string (guint elapsed, guint duration, gboolean show_remain
 	}
 }
 
+/**
+ * rb_string_list_equal:
+ * @a: list of strings to compare
+ * @b: other list of strings to compare
+ *
+ * Checks if @a and @b contain exactly the same set of strings,
+ * regardless of order.
+ *
+ * Return value: %TRUE if the lists contain all the same strings
+ */
 gboolean
 rb_string_list_equal (GList *a, GList *b)
 {
@@ -806,6 +818,15 @@ list_copy_cb (const char *s, GList **list)
 	*list = g_list_prepend (*list, g_strdup (s));
 }
 
+/**
+ * rb_string_list_copy:
+ * @list: list of strings to copy
+ *
+ * Creates a deep copy of @list.
+ *
+ * Return value: copied list, must be freed (and its contents freed)
+ *  by caller
+ */
 GList *
 rb_string_list_copy (GList *list)
 {
@@ -820,6 +841,15 @@ rb_string_list_copy (GList *list)
 	return copy;
 }
 
+/**
+ * rb_string_list_contains:
+ * @list: list to check
+ * @s: string to check for
+ *
+ * Checks if @list contains the string @s.
+ *
+ * Return value: %TRUE if found
+ */
 gboolean
 rb_string_list_contains (GList *list, const char *s)
 {
@@ -833,20 +863,38 @@ rb_string_list_contains (GList *list, const char *s)
 	return FALSE;
 }
 
+/**
+ * rb_list_destroy_free:
+ * @list: list to destroy
+ * @destroyer: function to call to free elements of @list
+ *
+ * Calls @destroyer for each element in @list, then frees @list.
+ */
 void
 rb_list_destroy_free (GList *list, GDestroyNotify destroyer)
 {
 	g_list_foreach (list, (GFunc)destroyer, NULL);
 	g_list_free (list);
-
 }
 
+/**
+ * rb_list_deep_free:
+ * @list: list to free
+ *
+ * Frees each element of @list and @list itself.
+ */
 void
 rb_list_deep_free (GList *list)
 {
 	rb_list_destroy_free (list, (GDestroyNotify)g_free);
 }
 
+/**
+ * rb_slist_deep_free:
+ * @list: list to free
+ *
+ * Frees each element of @list and @list itself.
+ */
 void
 rb_slist_deep_free (GSList *list)
 {
@@ -866,6 +914,15 @@ collate_values_cb (gpointer key, gpointer value, GList **list)
 	*list = g_list_prepend (*list, value);
 }
 
+/**
+ * rb_collate_hash_table_keys:
+ * @table: #GHashTable to collate
+ *
+ * Returns a #GList containing all keys from @table.  The keys are
+ * not copied.
+ *
+ * Return value: #GList of keys, must be freed by caller
+ */
 GList*
 rb_collate_hash_table_keys (GHashTable *table)
 {
@@ -877,6 +934,15 @@ rb_collate_hash_table_keys (GHashTable *table)
 	return list;
 }
 
+/**
+ * rb_collate_hash_table_values:
+ * @table: #GHashTable to collate
+ *
+ * Returns a #GList containing all values from @table.  The values are
+ * not copied.
+ *
+ * Return value: #GList of values, must be freed by caller
+ */
 GList*
 rb_collate_hash_table_values (GHashTable *table)
 {
@@ -888,11 +954,15 @@ rb_collate_hash_table_values (GHashTable *table)
 	return list;
 }
 
-/*
- * hacked up version of gnome_vfs_uri_list_parse,
- * that it doesn't strip #s and and returns strings. 
+/**
+ * rb_uri_list_parse:
+ * @uri_list: string containing URIs to parse
+ *
+ * Converts a single string containing a list of URIs into
+ * a #GList of URI strings.
+ *
+ * Return value: #GList of URI strings, must be deep-freed by caller
  */
-
 GList *
 rb_uri_list_parse (const char *uri_list)
 {
@@ -935,19 +1005,41 @@ rb_uri_list_parse (const char *uri_list)
 	return g_list_reverse (result);
 }
 
-const gchar*
-rb_mime_get_friendly_name (const gchar *mime_type)
+/**
+ * rb_mime_get_friendly_name:
+ * @mime_type: a MIME type
+ *
+ * Returns a human-friendly description of the MIME type @mime_type.
+ *
+ * Return value: type description, must be freed by caller
+ */
+char*
+rb_mime_get_friendly_name (const char *mime_type)
 {
-	const gchar *name = NULL;
+	gchar *name = NULL;
 	
 	if (name == NULL && mime_type)
-		name = gnome_vfs_mime_get_description (mime_type);
+		name = g_content_type_get_description (mime_type);
 	if (name == NULL)
-		name = _("Unknown");
+		name = g_strdup (_("Unknown"));
 
 	return name;
 }
 
+/**
+ * rb_signal_accumulator_object_handled:
+ * @hint: a #GSignalInvocationHint
+ * @return_accu: holds the accumulated return value
+ * @handler_return: holds the return value to be accumulated
+ * @dummy: user data (unused)
+ *
+ * A #GSignalAccumulator that aborts the signal emission after the
+ * first handler to return a value, and returns the value returned by
+ * that handler.  This is the opposite behaviour from what you get when
+ * no accumulator is specified, where the last signal handler wins.
+ *
+ * Return value: %FALSE to abort signal emission, %TRUE to continue
+ */
 gboolean
 rb_signal_accumulator_object_handled (GSignalInvocationHint *hint,
 				      GValue *return_accu,
@@ -966,6 +1058,65 @@ rb_signal_accumulator_object_handled (GSignalInvocationHint *hint,
 	return FALSE;
 }
 
+/**
+ * rb_signal_accumulator_value_array:
+ * @hint: a #GSignalInvocationHint
+ * @return_accu: holds the accumulated return value
+ * @handler_return: holds the return value to be accumulated
+ * @dummy: user data (unused)
+ *
+ * A #GSignalAccumulator used to combine all returned values into
+ * a #GValueArray.
+ *
+ * Return value: %FALSE to abort signal emission, %TRUE to continue
+ */
+gboolean
+rb_signal_accumulator_value_array (GSignalInvocationHint *hint,
+				   GValue *return_accu,
+				   const GValue *handler_return,
+				   gpointer dummy)
+{
+	GValueArray *a;
+	GValueArray *b;
+	int i;
+
+	if (handler_return == NULL)
+		return TRUE;
+
+	a = NULL;
+	if (G_VALUE_HOLDS_BOXED (return_accu)) {
+		a = g_value_get_boxed (return_accu);
+		if (a != NULL) {
+			a = g_value_array_copy (a);
+		}
+	}
+
+	if (a == NULL) {
+		a = g_value_array_new (1);
+	}
+
+	if (G_VALUE_HOLDS_BOXED (handler_return)) {
+		b = g_value_get_boxed (handler_return);
+		for (i=0; i < b->n_values; i++) {
+			GValue *z = g_value_array_get_nth (b, i);
+			a = g_value_array_append (a, z);
+		}
+	}
+
+	g_value_unset (return_accu);
+	g_value_init (return_accu, G_TYPE_VALUE_ARRAY);
+	g_value_set_boxed (return_accu, a);
+	return TRUE;
+}
+
+/**
+ * rb_value_array_append_data:
+ * @array: #GValueArray to append to
+ * @type: #GType of the value being appended
+ * @Varargs: value to append
+ *
+ * Appends a single value to @array, collecting it from @Varargs.
+ */
 void
 rb_value_array_append_data (GValueArray *array, GType type, ...)
 {
@@ -986,6 +1137,13 @@ rb_value_array_append_data (GValueArray *array, GType type, ...)
 	va_end (va);
 }
 
+/**
+ * rb_value_free:
+ * @val: a #GValue
+ *
+ * Unsets and frees @val.  @val must have been allocated using
+ * @g_slice_new or @g_slice_new0.
+ */
 void
 rb_value_free (GValue *val)
 {
@@ -993,6 +1151,16 @@ rb_value_free (GValue *val)
 	g_slice_free (GValue, val);
 }
 
+/**
+ * rb_str_in_strv:
+ * @needle: string to search for
+ * @haystack: array of strings to search
+ *
+ * Checks if @needle is present in the NULL-terminated string
+ * array @haystack.
+ *
+ * Return value: %TRUE if found
+ */
 gboolean
 rb_str_in_strv (const char *needle, char **haystack)
 {
@@ -1055,6 +1223,8 @@ rb_set_tree_view_column_fixed_width (GtkWidget  *treeview,
  *
  * Creates a new #GdkPixbuf from the original one, for a target of
  * size, respecting the aspect ratio of the image.
+ *
+ * Return value: scaled #GdkPixbuf
  */
 GdkPixbuf *
 rb_scale_pixbuf_to_size (GdkPixbuf *pixbuf, GtkIconSize size)
@@ -1081,4 +1251,3 @@ rb_scale_pixbuf_to_size (GdkPixbuf *pixbuf, GtkIconSize size)
 
 	return gdk_pixbuf_scale_simple (pixbuf, d_width, d_height, GDK_INTERP_BILINEAR);
 }
-
