@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for Audio CD source object
- *
  *  Copyright (C) 2005 James Livingston  <doclivingston@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -53,7 +51,7 @@ typedef struct
 	RBRemovableMediaSourceClass parent;
 } RBAudioCdSourceClass;
 
-RBRemovableMediaSource *	rb_audiocd_source_new		(RBPlugin *plugin,
+RBSource *		rb_audiocd_source_new			(RBPlugin *plugin,
 								 RBShell  *shell,
 								 GVolume  *volume);
 GType			rb_audiocd_source_get_type		(void);
