@@ -122,19 +122,17 @@ impl_activate (RBPlugin *bplugin,
 	       RBShell *shell)
 {
 	RBAudioscrobblerPlugin *plugin = RB_AUDIOSCROBBLER_PLUGIN (bplugin);
-	RBProxyConfig *proxy_config;
 	GtkUIManager *uimanager = NULL;
 	gboolean no_registration;
 	char *file;
 
-    /* Source icon data */
-    gchar *icon_filename;
-    gint icon_size;
-    GdkPixbuf *icon_pixbuf;
+	/* Source icon data */
+	gchar *icon_filename;
+	gint icon_size;
+	GdkPixbuf *icon_pixbuf;
 
 	g_assert (plugin->audioscrobbler == NULL);
 	g_object_get (G_OBJECT (shell),
-		      "proxy-config", &proxy_config,
 		      "no-registration", &no_registration,
 		      "ui-manager", &uimanager,
 		      NULL);
@@ -145,10 +143,8 @@ impl_activate (RBPlugin *bplugin,
 	 * last.fm only allows one active client per user.
 	 */
 	if (!no_registration) {
-		plugin->audioscrobbler = rb_audioscrobbler_new (RB_SHELL_PLAYER (rb_shell_get_player (shell)),
-								proxy_config);
+		plugin->audioscrobbler = rb_audioscrobbler_new (RB_SHELL_PLAYER (rb_shell_get_player (shell)));
 	}
-	g_object_unref (G_OBJECT (proxy_config));
 
 	file = rb_plugin_find_file (bplugin, "audioscrobbler-ui.xml");
 	plugin->ui_merge_id = gtk_ui_manager_add_ui_from_file (uimanager,
@@ -158,14 +154,13 @@ impl_activate (RBPlugin *bplugin,
 
 	plugin->lastfm_source = rb_lastfm_source_new (bplugin, shell);
     
-    icon_filename = rb_plugin_find_file (bplugin, "as-icon.png");
-    gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR, &icon_size, NULL);
-    icon_pixbuf = gdk_pixbuf_new_from_file_at_size (icon_filename,
-                                                    icon_size, icon_size,
-                                                    NULL);
-    g_free (icon_filename);
-    rb_source_set_pixbuf (plugin->lastfm_source, icon_pixbuf);
-    g_object_unref (icon_pixbuf);
+	icon_filename = rb_plugin_find_file (bplugin, "as-icon.png");
+	gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR, &icon_size, NULL);
+	icon_pixbuf = gdk_pixbuf_new_from_file_at_size (icon_filename, icon_size, icon_size, NULL);
+
+	g_free (icon_filename);
+	rb_source_set_pixbuf (plugin->lastfm_source, icon_pixbuf);
+	g_object_unref (icon_pixbuf);
     
 	rb_shell_append_source (shell, plugin->lastfm_source, NULL);
 
@@ -228,7 +223,8 @@ impl_create_configure_dialog (RBPlugin *bplugin)
 				  plugin);
 		gtk_widget_hide_on_delete (plugin->preferences);
 
-		gtk_container_add (GTK_CONTAINER (GTK_DIALOG (plugin->preferences)->vbox), widget);
+		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (plugin->preferences))),
+				   widget);
 	}
 
 	gtk_widget_show_all (plugin->preferences);
