@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of last.fm station source object
  *
  *  Copyright (C) 2006 Matt Novenstern <fisxoj@gmail.com>
  *  Copyright (C) 2008 Jonathan Matthew <jonathan@d14n.org>
@@ -79,6 +77,8 @@
 #include "rb-play-order.h"
 #include "rb-lastfm-play-order.h"
 
+#include "gseal-gtk-compat.h"
+
 #define LASTFM_URL "ws.audioscrobbler.com"
 #define RB_LASTFM_PLATFORM "linux"
 #define RB_LASTFM_VERSION "1.5"
@@ -123,8 +123,7 @@ static void queue_ban_track (RBLastfmSource *source);
 
 static void rb_lastfm_source_class_init (RBLastfmSourceClass *klass);
 static void rb_lastfm_source_init (RBLastfmSource *source);
-static GObject *rb_lastfm_source_constructor (GType type, guint n_construct_properties,
-					      GObjectConstructParam *construct_properties);
+static void rb_lastfm_source_constructed (GObject *object);
 static void rb_lastfm_source_finalize (GObject *object);
 static void rb_lastfm_source_set_property (GObject *object,
 			                  guint prop_id,
@@ -308,7 +307,7 @@ rb_lastfm_source_class_init (RBLastfmSourceClass *klass)
 
 	object_class->finalize = rb_lastfm_source_finalize;
 	object_class->dispose = rb_lastfm_source_dispose;
-	object_class->constructor = rb_lastfm_source_constructor;
+	object_class->constructed = rb_lastfm_source_constructed;
 
 	object_class->set_property = rb_lastfm_source_set_property;
 	object_class->get_property = rb_lastfm_source_get_property;
@@ -449,12 +448,10 @@ rb_lastfm_source_finalize (GObject *object)
 	G_OBJECT_CLASS (rb_lastfm_source_parent_class)->finalize (object);
 }
 
-static GObject *
-rb_lastfm_source_constructor (GType type, guint n_construct_properties,
-			      GObjectConstructParam *construct_properties)
+static void
+rb_lastfm_source_constructed (GObject *object)
 {
 	RBLastfmSource *source;
-	RBLastfmSourceClass *klass;
 	RBShell *shell;
 	GtkWidget *editor_vbox;
 	GtkWidget *editor_box;
@@ -464,17 +461,15 @@ rb_lastfm_source_constructor (GType type, guint n_construct_properties,
 	RhythmDBQueryModel *station_query_model;
 	int i;
 
-	klass = RB_LASTFM_SOURCE_CLASS (g_type_class_peek (RB_TYPE_LASTFM_SOURCE));
+	RB_CHAIN_GOBJECT_METHOD (rb_lastfm_source_parent_class, constructed, object);
+	source = RB_LASTFM_SOURCE (object);
 
-	source = RB_LASTFM_SOURCE (G_OBJECT_CLASS (rb_lastfm_source_parent_class)
-			->constructor (type, n_construct_properties, construct_properties));
-
-	g_object_get (G_OBJECT (source), "shell", &shell, NULL);
-	g_object_get (G_OBJECT (shell),
+	g_object_get (source, "shell", &shell, NULL);
+	g_object_get (shell,
 		      "db", &source->priv->db,
 		      "shell-player", &source->priv->shell_player,
 		      NULL);
-	g_object_unref (G_OBJECT (shell));
+	g_object_unref (shell);
 
 	g_signal_connect_object (source->priv->db,
 				 "entry-added",
@@ -611,8 +606,6 @@ rb_lastfm_source_constructor (GType type, guint n_construct_properties,
 	rb_entry_view_set_model (source->priv->tracks, source->priv->query_model);
 	
 	g_object_set (source, "query-model", source->priv->query_model, NULL);
-
-	return G_OBJECT (source);
 }
 
 static void
@@ -774,7 +767,7 @@ set_message_area_text_and_icon (RBLastfmSource *source,
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
   	if (secondary_text != NULL) {
@@ -784,7 +777,7 @@ set_message_area_text_and_icon (RBLastfmSource *source,
 		g_free (secondary_markup);
 		gtk_widget_show (secondary_label);
 		gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-		GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (secondary_label, TRUE);
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -1196,7 +1189,7 @@ impl_receive_drag (RBSource *asource, GtkSelectionData *selection_data)
 	char *title = NULL;
 	RBLastfmSource *source = RB_LASTFM_SOURCE (asource);
 
-	uri = (char *)selection_data->data;
+	uri = (char *) gtk_selection_data_get_data (selection_data);
 	rb_debug ("parsing uri %s", uri);
 
 	if (strstr (uri, "lastfm://") == NULL)
