@@ -157,7 +157,8 @@ rb_disc_recorder_plugin_start_burning (RBDiscRecorderPlugin *pi,
 					  const char *path,
 					  gboolean copy)
 {
-	GtkWindow *main_window;
+	GtkWidget *main_window;
+	GdkScreen *screen;
 	GPtrArray *array;
 	char **args, *xid_str;
 	GError *error = NULL;
@@ -171,8 +172,9 @@ rb_disc_recorder_plugin_start_burning (RBDiscRecorderPlugin *pi,
 		g_ptr_array_add (array, "-r");
 	g_ptr_array_add (array, (gpointer) path);
 
-	main_window =GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (pi->selected_source)));
-	if (main_window && GTK_WIDGET (main_window)->window) {
+	main_window = gtk_widget_get_toplevel (GTK_WIDGET (pi->selected_source));
+	screen = gtk_widget_get_screen (main_window);
+	if (main_window && main_window->window) {
 		int xid;
 		xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (main_window)->window));
 		xid_str = g_strdup_printf ("%d", xid);
@@ -186,7 +188,7 @@ rb_disc_recorder_plugin_start_burning (RBDiscRecorderPlugin *pi,
 	args = (char **) g_ptr_array_free (array, FALSE);
 
 	ret = TRUE;
-	if (!g_spawn_async (NULL, args, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error)) {
+	if (!gdk_spawn_on_screen (screen, NULL, args, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_FILE_AND_ARGV_ZERO, NULL, NULL, NULL, &error)) {
 		if (copy != FALSE) {
 			rb_error_dialog (GTK_WINDOW (main_window),
 					 _("Rhythmbox could not duplicate the disc"),
@@ -292,15 +294,15 @@ rb_disc_recorder_plugin_write_audio_project (const gchar 	*name,
 	if (success < 0)
 		goto error;
 
-	success = xmlTextWriterStartElement (project, (xmlChar *) "audio");
-	if (success < 0)
-		goto error;
-
         do {
 		RhythmDBEntry  *entry;
 		const char *str;
 		xmlChar *escaped;
 
+		success = xmlTextWriterStartElement (project, (xmlChar *) "audio");
+		if (success < 0)
+			goto error;
+
 		gtk_tree_model_get (model, &iter, 0, &entry, -1);
 
 		str = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_LOCATION);
@@ -373,11 +375,11 @@ rb_disc_recorder_plugin_write_audio_project (const gchar 	*name,
 				goto error;
 		}
 		*/
-        } while (gtk_tree_model_iter_next (model, &iter));
 
-	success = xmlTextWriterEndElement (project); /* audio */
-	if (success < 0)
-		goto error;
+		success = xmlTextWriterEndElement (project); /* audio */
+		if (success < 0)
+			goto error;
+        } while (gtk_tree_model_iter_next (model, &iter));
 
 	success = xmlTextWriterEndElement (project); /* track */
 	if (success < 0)
