@@ -3,8 +3,11 @@
 
 # Copyright 2008, Frank Scholz <coherence@beebits.net>
 
+import os.path
 import urllib
 
+from twisted.python import failure
+
 import rhythmdb
 
 from coherence.upnp.core.soap_service import errorCode
@@ -26,27 +29,25 @@ class RhythmboxPlayer(log.Loggable):
     logCategory = 'rb_media_renderer'
 
     implements = ['MediaRenderer']
-    vendor_value_defaults = {'RenderingControl': {'A_ARG_TYPE_Channel':'Master'}}
+    vendor_value_defaults = {'RenderingControl': {'A_ARG_TYPE_Channel':'Master'},
+                             'AVTransport': {'A_ARG_TYPE_SeekMode':('ABS_TIME','REL_TIME','TRACK_NR')}}
     vendor_range_defaults = {'RenderingControl': {'Volume': {'maximum':100}}}
 
     def __init__(self, device, **kwargs):
         self.warning("__init__ RhythmboxPlayer %r", kwargs)
         self.shell = kwargs['shell']
         self.server = device
+        self.rb_mediaserver = kwargs['rb_mediaserver']
 
         self.player = None
+        self.entry = None
         self.metadata = None
-        self.host = '127.0.0.1'
-        self.name = "Rhythmbox on %s" % self.server.coherence.hostname
+        try:
+            self.name = kwargs['name']
+        except KeyError:
+            self.name = "Rhythmbox on %s" % self.server.coherence.hostname
 
         self.player = self.shell.get_player()
-        self.player.connect ('playing-song-changed',
-                                 self.playing_song_changed),
-        self.player.connect ('playing-changed',
-                                 self.playing_changed)
-        self.player.connect ('elapsed-changed',
-                                 self.elapsed_changed)
-        self.player.connect("notify::volume", self.volume_changed)
         louie.send('Coherence.UPnP.Backend.init_completed', None, backend=self)
 
         self.playing = False
@@ -62,13 +63,13 @@ class RhythmboxPlayer(log.Loggable):
 
     def volume_changed(self, player, parameter):
         self.volume = self.player.props.volume
-        self.warning('volume_changed to %r', self.volume)
+        self.info('volume_changed to %r', self.volume)
         if self.volume > 0:
             rcs_id = self.server.connection_manager_server.lookup_rcs_id(self.current_connection_id)
             self.server.rendering_control_server.set_variable(rcs_id, 'Volume', self.volume*100)
 
     def playing_song_changed(self, player, entry):
-        self.warning("playing_song_changed %r", entry)
+        self.info("playing_song_changed %r", entry)
         if self.server != None:
             connection_id = self.server.connection_manager_server.lookup_avt_id(self.current_connection_id)
         if entry == None:
@@ -78,7 +79,7 @@ class RhythmboxPlayer(log.Loggable):
             self.metadata = None
             self.duration = None
         else:
-            self.id = self.shell.props.db.entry_get (entry, rhythmdb.PROP_ENTRY_ID)
+            id = self.shell.props.db.entry_get (entry, rhythmdb.PROP_ENTRY_ID)
             bitrate = self.shell.props.db.entry_get(entry, rhythmdb.PROP_BITRATE) * 1024 / 8
             # Duration is in HH:MM:SS format
             seconds = self.shell.props.db.entry_get(entry, rhythmdb.PROP_DURATION)
@@ -95,43 +96,62 @@ class RhythmboxPlayer(log.Loggable):
             size = self.shell.props.db.entry_get(entry, rhythmdb.PROP_FILE_SIZE)
 
             # create item
-            item = DIDLLite.MusicTrack(self.id + TRACK_COUNT)
+            item = DIDLLite.MusicTrack(id + TRACK_COUNT,'101')
             item.album = self.shell.props.db.entry_get(entry, rhythmdb.PROP_ALBUM)
             item.artist = self.shell.props.db.entry_get(entry, rhythmdb.PROP_ARTIST)
             item.genre = self.shell.props.db.entry_get(entry, rhythmdb.PROP_GENRE)
             item.originalTrackNumber = str(self.shell.props.db.entry_get (entry, rhythmdb.PROP_TRACK_NUMBER))
             item.title = self.shell.props.db.entry_get(entry, rhythmdb.PROP_TITLE) # much nicer if it was entry.title
 
+            cover = self.shell.props.db.entry_request_extra_metadata(entry, "rb:coverArt-uri")
+            if cover != None:
+                _,ext =  os.path.splitext(cover)
+                item.albumArtURI = ''.join((self.server.coherence.urlbase+str(self.rb_mediaserver.uuid)[5:]+'/'+ str(int(id) + TRACK_COUNT),'?cover',ext))
+
             item.res = []
 
-            uri = self.shell.props.db.entry_get(entry, rhythmdb.PROP_LOCATION)
-            if uri.startswith("file://"):
-                location = unicode(urllib.unquote(uri[len("file://"):]))
+            location = self.shell.props.db.entry_get(entry, rhythmdb.PROP_LOCATION)
+            if location.startswith("file://"):
+                location = unicode(urllib.unquote(location[len("file://"):]))
 
-                # add a fake resource for the moment
-                res = DIDLLite.Resource(location, 'http-get:*:%s:*' % mimetype)
-                if size > 0:
-                    res.size = size
-                if self.duration > 0:
-                    res.duration = self.duration
-                if bitrate > 0:
-                    res.bitrate = str(bitrate)
-                item.res.append(res)
+            uri = ''.join((self.server.coherence.urlbase+str(self.rb_mediaserver.uuid)[5:]+'/'+ str(int(id) + TRACK_COUNT)))
+
+            res = DIDLLite.Resource(uri, 'http-get:*:%s:*' % mimetype)
+            if size > 0:
+                res.size = size
+            if self.duration > 0:
+                res.duration = self.duration
+            if bitrate > 0:
+                res.bitrate = str(bitrate)
+            item.res.append(res)
+
+            # add internal resource
+            res = DIDLLite.Resource('track-%d' % id, 'rhythmbox:%s:%s:*' % (self.server.coherence.hostname, mimetype))
+            if size > 0:
+                res.size = size
+            if self.duration > 0:
+                res.duration = str(self.duration)
+            if bitrate > 0:
+                res.bitrate = str(bitrate)
+            item.res.append(res)
 
             elt = DIDLLite.DIDLElement()
             elt.addItem(item)
             self.metadata = elt.toString()
             self.entry = entry
             if self.server != None:
+                self.server.av_transport_server.set_variable(connection_id, 'CurrentTrackURI',uri)
+                self.server.av_transport_server.set_variable(connection_id, 'AVTransportURI',uri)
                 self.server.av_transport_server.set_variable(connection_id, 'AVTransportURIMetaData',self.metadata)
                 self.server.av_transport_server.set_variable(connection_id, 'CurrentTrackMetaData',self.metadata)
-            self.warning("playing_song_changed %r", self.metadata)
+            self.info("playing_song_changed %r", self.metadata)
         if self.server != None:
+            self.server.av_transport_server.set_variable(connection_id, 'CurrentTransportActions','PLAY,STOP,PAUSE,SEEK,NEXT,PREVIOUS')
             self.server.av_transport_server.set_variable(connection_id, 'RelativeTimePosition', '00:00:00')
             self.server.av_transport_server.set_variable(connection_id, 'AbsoluteTimePosition', '00:00:00')
 
     def playing_changed(self, player, state):
-        self.warning("playing_changed", state)
+        self.info("playing_changed", state)
         if state is True:
             transport_state = 'PLAYING'
         else:
@@ -149,10 +169,10 @@ class RhythmboxPlayer(log.Loggable):
         except:
             duration = None
         self.update_position(position,duration)
-        self.warning("playing_changed %r %r ", position, duration)
+        self.info("playing_changed %r %r ", position, duration)
 
     def elapsed_changed(self, player, time):
-        self.warning("elapsed_changed %r %r", player, time)
+        self.info("elapsed_changed %r %r", player, time)
         try:
             duration = player.get_playing_song_duration()
         except:
@@ -161,7 +181,7 @@ class RhythmboxPlayer(log.Loggable):
 
     def update(self, state):
 
-        self.warning("update %r", state)
+        self.info("update %r", state)
 
         if state in ('STOPPED','READY'):
             transport_state = 'STOPPED'
@@ -180,11 +200,11 @@ class RhythmboxPlayer(log.Loggable):
 
 
     def update_position(self, position,duration):
-        self.warning("update_position %r %r", position,duration)
+        self.info("update_position %r %r", position,duration)
 
         if self.server != None:
             connection_id = self.server.connection_manager_server.lookup_avt_id(self.current_connection_id)
-            self.server.av_transport_server.set_variable(connection_id, 'CurrentTrack', 0)
+            self.server.av_transport_server.set_variable(connection_id, 'CurrentTrack', 1)
 
         if position is not None:
             m,s = divmod( position, 60)
@@ -206,7 +226,7 @@ class RhythmboxPlayer(log.Loggable):
 
             if self.duration is None:
                 if self.metadata is not None:
-                    self.warning("update_position %r", self.metadata)
+                    self.info("update_position %r", self.metadata)
                     elt = DIDLLite.DIDLElement.fromString(self.metadata)
                     for item in elt:
                         for res in item.findall('res'):
@@ -220,29 +240,36 @@ class RhythmboxPlayer(log.Loggable):
                 self.duration = duration
 
     def load( self, uri, metadata):
-        self.warning("player load %r %r", uri, metadata)
+        self.info("player load %r %r", uri, metadata)
         #self.shell.load_uri(uri,play=False)
         self.duration = None
         self.metadata = metadata
         self.tags = {}
 
-        if len(self.metadata)>0:
-            elt = DIDLLite.DIDLElement.fromString(self.metadata)
+        was_playing = self.playing
+
+        if was_playing == True:
+            self.stop()
+
+        if len(metadata)>0:
+            elt = DIDLLite.DIDLElement.fromString(metadata)
             if elt.numItems() == 1:
                 item = elt.getItems()[0]
 
-                self.entry = self.shell.props.db.entry_lookup_by_location(uri)
-                self.warning("check for entry %r %r", self.entry, item.server_uuid)
+                if uri.startswith('track-'):
+                    self.entry = self.shell.props.db.entry_lookup_by_id(int(uri[6:]))
+                else:
+                    self.entry = self.shell.props.db.entry_lookup_by_location(uri)
+                self.info("check for entry %r %r %r", self.entry,item.server_uuid,uri)
                 if self.entry == None:
                     if item.server_uuid is not None:
                         entry_type = self.shell.props.db.entry_register_type("CoherenceUpnp:" + item.server_uuid)
                         self.entry = self.shell.props.db.entry_new(entry_type, uri)
-                        self.warning("create new entry %r", self.entry)
+                        self.info("create new entry %r", self.entry)
                     else:
-                        self.shell.load_uri(uri,play=False)
-                        self.entry = self.shell.props.db.entry_lookup_by_location(uri)
-                        self.warning("load and check for entry %r", self.entry)
-
+                        entry_type = self.shell.props.db.entry_register_type("CoherencePlayer")
+                        self.entry = self.shell.props.db.entry_new(entry_type, uri)
+                        self.info("load and check for entry %r", self.entry)
 
                 duration = None
                 size = None
@@ -283,13 +310,20 @@ class RhythmboxPlayer(log.Loggable):
                     self.shell.props.db.set(self.entry, rhythmdb.PROP_FILE_SIZE,int(size))
 
         else:
-            self.shell.load_uri(uri,play=False)
-            self.entry = self.shell.props.db.entry_lookup_by_location(uri)
+            if uri.startswith('track-'):
+                self.entry = self.shell.props.db.entry_lookup_by_id(int(uri[6:]))
+            else:
+                #self.shell.load_uri(uri,play=False)
+                #self.entry = self.shell.props.db.entry_lookup_by_location(uri)
+                entry_type = self.shell.props.db.entry_register_type("CoherencePlayer")
+                self.entry = self.shell.props.db.entry_new(entry_type, uri)
+
 
         self.playing = False
+        self.metadata = metadata
 
         connection_id = self.server.connection_manager_server.lookup_avt_id(self.current_connection_id)
-        self.server.av_transport_server.set_variable(connection_id, 'CurrentTransportActions','Play,Stop,Pause')
+        self.server.av_transport_server.set_variable(connection_id, 'CurrentTransportActions','PLAY,STOP,PAUSE,SEEK,NEXT,PREVIOUS')
         self.server.av_transport_server.set_variable(connection_id, 'NumberOfTracks',1)
         self.server.av_transport_server.set_variable(connection_id, 'CurrentTrackURI',uri)
         self.server.av_transport_server.set_variable(connection_id, 'AVTransportURI',uri)
@@ -297,12 +331,15 @@ class RhythmboxPlayer(log.Loggable):
         self.server.av_transport_server.set_variable(connection_id, 'CurrentTrackURI',uri)
         self.server.av_transport_server.set_variable(connection_id, 'CurrentTrackMetaData',metadata)
 
+        if was_playing == True:
+            self.play()
+
     def start(self, uri):
         self.load(uri)
         self.play()
 
     def stop(self):
-        self.warning("player stop")
+        self.info("player stop")
 
         self.player.stop()
         self.playing = False
@@ -311,10 +348,13 @@ class RhythmboxPlayer(log.Loggable):
         #                     'TransportState', 'STOPPED')
 
     def play(self):
-        self.warning("player play")
+        self.info("player play")
 
         if self.playing == False:
-            self.player.play_entry(self.entry)
+            if self.entry:
+               self.player.play_entry(self.entry)
+            else:
+               self.player.playpause()
             self.playing = True
         else:
             self.player.playpause()
@@ -328,12 +368,14 @@ class RhythmboxPlayer(log.Loggable):
         #    self.server.connection_manager_server.lookup_avt_id(self.current_connection_id),\
         #                     'TransportState', 'PAUSED_PLAYBACK')
 
-    def seek(self, location):
+    def seek(self, location, old_state):
         """
-        @param location:    simple number = time to seek to, in seconds
-                            +nL = relative seek forward n seconds
+        @param location:    +nL = relative seek forward n seconds
                             -nL = relative seek backwards n seconds
         """
+        self.info("player seek %r", location)
+        self.player.seek(location)
+        self.server.av_transport_server.set_variable(0, 'TransportState', old_state)
 
     def mute(self):
         self.muted_volume = self.volume
@@ -354,11 +396,11 @@ class RhythmboxPlayer(log.Loggable):
 
     def get_volume(self):
         self.volume = self.player.get_volume()
-        self.warning("get_volume %r", self.volume)
+        self.info("get_volume %r", self.volume)
         return self.volume * 100
 
     def set_volume(self, volume):
-        self.warning("set_volume %r", volume)
+        self.info("set_volume %r", volume)
         volume = int(volume)
         if volume < 0:
             volume=0
@@ -368,9 +410,17 @@ class RhythmboxPlayer(log.Loggable):
         self.player.set_volume(float(volume/100.0))
 
     def upnp_init(self):
+        self.player.connect ('playing-song-changed',
+                                 self.playing_song_changed),
+        self.player.connect ('playing-changed',
+                                 self.playing_changed)
+        self.player.connect ('elapsed-changed',
+                                 self.elapsed_changed)
+        self.player.connect("notify::volume", self.volume_changed)
+
         self.current_connection_id = None
         self.server.connection_manager_server.set_variable(0, 'SinkProtocolInfo',
-                            ['internal:%s:*:*' % self.host,
+                            ['rhythmbox:%s:audio/mpeg:*' % self.server.coherence.hostname,
                              'http-get:*:audio/mpeg:*'],
                             default=True)
         self.server.av_transport_server.set_variable(0, 'TransportState', 'NO_MEDIA_PRESENT', default=True)
@@ -386,6 +436,16 @@ class RhythmboxPlayer(log.Loggable):
         self.play()
         return {}
 
+    def upnp_Previous(self, *args, **kwargs):
+        InstanceID = int(kwargs['InstanceID'])
+        self.player.do_previous()
+        return {}
+
+    def upnp_Next(self, *args, **kwargs):
+        InstanceID = int(kwargs['InstanceID'])
+        self.player.do_next()
+        return {}
+
     def upnp_Pause(self, *args, **kwargs):
         InstanceID = int(kwargs['InstanceID'])
         self.pause()
@@ -396,6 +456,38 @@ class RhythmboxPlayer(log.Loggable):
         self.stop()
         return {}
 
+    def upnp_Seek(self, *args, **kwargs):
+        InstanceID = int(kwargs['InstanceID'])
+        Unit = kwargs['Unit']
+        Target = kwargs['Target']
+        if Unit in ['ABS_TIME','REL_TIME']:
+            old_state = self.server.av_transport_server.get_variable('TransportState').value
+            self.server.av_transport_server.set_variable(0, 'TransportState', 'TRANSITIONING')
+
+            sign = 1
+            if Target[0] == '+':
+                Target = Target[1:]
+            if Target[0] == '-':
+                Target = Target[1:]
+                sign = -1
+            h,m,s = Target.split(':')
+            seconds = int(h)*3600 + int(m)*60 + int(s)
+
+            if Unit == 'ABS_TIME':
+                position = self.player.get_playing_time()
+                self.seek(seconds-position, old_state)
+            elif Unit == 'REL_TIME':
+                self.seek(seconds*sign, old_state)
+        return {}
+
+    def upnp_Next(self,*args,**kwargs):
+        self.player.do_next()
+        return {}
+
+    def upnp_Previous(self,*args,**kwargs):
+        self.player.do_previous()
+        return {}
+
     def upnp_SetAVTransportURI(self, *args, **kwargs):
         InstanceID = int(kwargs['InstanceID'])
         CurrentURI = kwargs['CurrentURI']
@@ -404,12 +496,13 @@ class RhythmboxPlayer(log.Loggable):
         #print '>>>', local_protocol_infos
         if len(CurrentURIMetaData)==0:
             self.load(CurrentURI,CurrentURIMetaData)
+            return {}
         else:
             elt = DIDLLite.DIDLElement.fromString(CurrentURIMetaData)
             #import pdb; pdb.set_trace()
             if elt.numItems() == 1:
                 item = elt.getItems()[0]
-                res = item.res.get_matching(local_protocol_infos, protocol_type='internal')
+                res = item.res.get_matching(local_protocol_infos, protocol_type='rhythmbox')
                 if len(res) == 0:
                     res = item.res.get_matching(local_protocol_infos)
                 if len(res) > 0:
