@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for iPod source object
- *
  *  Copyright (C) 2004 Christophe Fergeau  <teuf@gnome.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -31,9 +29,10 @@
 #define __RB_IPOD_SOURCE_H
 
 #include "rb-shell.h"
-#include "rb-removable-media-source.h"
+#include "rb-media-player-source.h"
 #include "rhythmdb.h"
 #include "rb-plugin.h"
+#include "mediaplayerid.h"
 
 G_BEGIN_DECLS
 
@@ -46,17 +45,18 @@ G_BEGIN_DECLS
 
 typedef struct
 {
-	RBRemovableMediaSource parent;
+	RBMediaPlayerSource parent;
 } RBiPodSource;
 
 typedef struct
 {
-	RBRemovableMediaSourceClass parent;
+	RBMediaPlayerSourceClass parent;
 } RBiPodSourceClass;
 
-RBRemovableMediaSource *rb_ipod_source_new		(RBPlugin *plugin,
+RBMediaPlayerSource    *rb_ipod_source_new		(RBPlugin *plugin,
 							 RBShell *shell,
-                                                         GMount *mount);
+                                                         GMount *mount,
+							 MPIDDevice *device_info);
 GType			rb_ipod_source_get_type		(void);
 GType                   rb_ipod_source_register_type    (GTypeModule *module);
 
@@ -66,7 +66,7 @@ void			rb_ipod_source_remove_playlist	(RBiPodSource *ipod_source,
 
 void			rb_ipod_source_show_properties	(RBiPodSource *source);
 
-void			rb_ipod_source_trash_entries	(RBiPodSource *source,
+void			rb_ipod_source_delete_entries	(RBiPodSource *source,
 							 GList *entries);
 
 G_END_DECLS
