@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of internet radio station properties dialog
  *
  *  Copyright (C) 2002 Colin Walters <walters@gnu.org>
  *
@@ -42,11 +40,11 @@
 #include "rb-dialog.h"
 #include "rb-rating.h"
 #include "rb-plugin.h"
+#include "rb-util.h"
 
 static void rb_station_properties_dialog_class_init (RBStationPropertiesDialogClass *klass);
 static void rb_station_properties_dialog_init (RBStationPropertiesDialog *dialog);
-static GObject *rb_station_properties_dialog_constructor(GType type, guint n_construct_properties,
-						    GObjectConstructParam *construct_properties);
+static void rb_station_properties_dialog_constructed (GObject *object);
 static void rb_station_properties_dialog_dispose (GObject *object);
 static void rb_station_properties_dialog_finalize (GObject *object);
 static void rb_station_properties_dialog_set_property (GObject *object,
@@ -119,7 +117,7 @@ rb_station_properties_dialog_class_init (RBStationPropertiesDialogClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	object_class->constructor = rb_station_properties_dialog_constructor;
+	object_class->constructed = rb_station_properties_dialog_constructed;
 	object_class->set_property = rb_station_properties_dialog_set_property;
 	object_class->get_property = rb_station_properties_dialog_get_property;
 
@@ -152,34 +150,35 @@ rb_station_properties_dialog_init (RBStationPropertiesDialog *dialog)
         dialog->priv = RB_STATION_PROPERTIES_DIALOG_GET_PRIVATE (dialog);
 }
 
-static GObject *
-rb_station_properties_dialog_constructor (GType type,
-					  guint n_construct_properties,
-					  GObjectConstructParam *construct_properties)
+static void
+rb_station_properties_dialog_constructed (GObject *object)
 {
 	RBStationPropertiesDialog *dialog;
+	GtkWidget *content_area;
 	GtkBuilder *builder;
 	char *builder_file;
 	AtkObject *lobj, *robj;
 
-	dialog = RB_STATION_PROPERTIES_DIALOG (G_OBJECT_CLASS (rb_station_properties_dialog_parent_class)
-			->constructor (type, n_construct_properties, construct_properties));
+	RB_CHAIN_GOBJECT_METHOD (rb_station_properties_dialog_parent_class, constructed, object);
+	dialog = RB_STATION_PROPERTIES_DIALOG (object);
 
-	g_signal_connect_object (G_OBJECT (dialog),
+	g_signal_connect_object (dialog,
 				 "response",
 				 G_CALLBACK (rb_station_properties_dialog_response_cb),
 				 dialog, 0);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 
 	builder_file = rb_plugin_find_file (dialog->priv->plugin, "station-properties.ui");
 	g_assert (builder_file != NULL);
 	builder = rb_builder_load (builder_file, dialog);
 	g_free (builder_file);
 
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox),
+	gtk_container_add (GTK_CONTAINER (content_area),
 			   GTK_WIDGET (gtk_builder_get_object (builder, "stationproperties")));
 
 	dialog->priv->close_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
@@ -227,8 +226,6 @@ rb_station_properties_dialog_constructor (GType type,
 	atk_object_add_relationship (robj, ATK_RELATION_LABELLED_BY, lobj);
 
 	g_object_unref (builder);
-
-	return G_OBJECT (dialog);
 }
 
 static void
