@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for mtp source object
- *
  *  Copyright (C) 2006 Peter Grundström  <pete@openfestis.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -32,6 +30,8 @@
 
 #include "rb-shell.h"
 #include "rb-removable-media-source.h"
+#include "rb-media-player-source.h"
+#include "rb-plugin.h"
 #include "rhythmdb.h"
 #include <libmtp.h>
 
@@ -46,19 +46,22 @@ G_BEGIN_DECLS
 
 typedef struct
 {
-	RBRemovableMediaSource parent;
+	RBMediaPlayerSource parent;
 } RBMtpSource;
 
 typedef struct
 {
-	RBRemovableMediaSourceClass parent;
+	RBMediaPlayerSourceClass parent;
 } RBMtpSourceClass;
 
+RBSource *		rb_mtp_source_new		(RBShell *shell,
+							 RBPlugin *plugin,
 #if defined(HAVE_GUDEV)
-RBSource *		rb_mtp_source_new		(RBShell *shell, LIBMTP_raw_device_t *device);
+							 GUdevDevice *udev_device,
 #else
-RBSource *		rb_mtp_source_new		(RBShell *shell, LIBMTP_raw_device_t *device, const char *udi);
+							 const char *udi,
 #endif
+							 LIBMTP_raw_device_t *device);
 
 GType			rb_mtp_source_get_type		(void);
 GType			rb_mtp_source_register_type	(GTypeModule *module);
