@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Header files for podcast download manager
  *
  *  Copyright (C) 2005 Renato Araujo Oliveira Filho - INdT <renato.filho@indt.org.br>
  *
@@ -9,7 +7,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -61,7 +59,7 @@ typedef struct
     void        (*start_download)    		(RBPodcastManager* pd, RhythmDBEntry *entry);
     void        (*finish_download)   		(RBPodcastManager* pd, RhythmDBEntry *entry);
     void        (*feed_updates_available)   	(RBPodcastManager* pd, RhythmDBEntry *entry);
-    void        (*process_error)	   	(RBPodcastManager* pd, const char *error);
+    gboolean    (*process_error)	   	(RBPodcastManager* pd, const char *error, gboolean existing);
 
 } RBPodcastManagerClass;
 
@@ -71,8 +69,7 @@ void                    rb_podcast_manager_download_entry  	(RBPodcastManager *p
 void		        rb_podcast_manager_cancel_download	(RBPodcastManager *pd, RhythmDBEntry *entry);
 void 			rb_podcast_manager_update_feeds 	(RBPodcastManager *pd);
 void                    rb_podcast_manager_start_sync  		(RBPodcastManager *pd);
-void            	rb_podcast_manager_set_remove_files    	(RBPodcastManager *pd, gboolean flag);
-gboolean 		rb_podcast_manager_get_remove_files	(RBPodcastManager *pd);
+void			rb_podcast_manager_delete_download	(RBPodcastManager *pd, RhythmDBEntry *entry);
 gboolean                rb_podcast_manager_remove_feed 		(RBPodcastManager *pd,
 								 const gchar* url,
 								 gboolean remove_files);
