@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Header for RhythmDB query result GtkTreeModel impl.
  *
  *  Copyright (C) 2003 Colin Walters <walters@rhythmbox.org>
  *
@@ -9,6 +7,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,7 +26,6 @@
  *
  */
 
-#include "config.h"
 #include <glib-object.h>
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -49,18 +54,20 @@ typedef enum {
 	RHYTHMDB_QUERY_MODEL_LIMIT_TIME,
 } RhythmDBQueryModelLimitType;
 
-typedef struct RhythmDBQueryModelPrivate RhythmDBQueryModelPrivate;
+typedef struct _RhythmDBQueryModel RhythmDBQueryModel;
+typedef struct _RhythmDBQueryModelClass RhythmDBQueryModelClass;
+typedef struct _RhythmDBQueryModelPrivate RhythmDBQueryModelPrivate;
 
-#define RHYTHMDB_QUERY_MODEL_SUGGESTED_UPDATE_CHUNK 32
+#define RHYTHMDB_QUERY_MODEL_SUGGESTED_UPDATE_CHUNK 1024
 
-typedef struct
+struct _RhythmDBQueryModel
 {
 	GObject parent;
 
 	RhythmDBQueryModelPrivate *priv;
-} RhythmDBQueryModel;
+};
 
-typedef struct
+struct _RhythmDBQueryModelClass
 {
 	GObjectClass parent;
 
@@ -78,8 +85,10 @@ typedef struct
 					 RhythmDBEntry *entry);
 	void	(*post_entry_delete)	(RhythmDBQueryModel *model,
 					 RhythmDBEntry *entry);
+	gboolean (*filter_entry_drop)	(RhythmDBQueryModel *model,
+					 RhythmDBEntry *entry);
 
-} RhythmDBQueryModelClass;
+};
 
 GType			rhythmdb_query_model_get_type		(void);
 
@@ -95,7 +104,7 @@ RhythmDBQueryModel *	rhythmdb_query_model_new_empty		(RhythmDB *db);
 void			rhythmdb_query_model_copy_contents	(RhythmDBQueryModel *dest,
 								 RhythmDBQueryModel *src);
 
-void			rhythmdb_query_model_chain		(RhythmDBQueryModel *child,
+void			rhythmdb_query_model_chain		(RhythmDBQueryModel *model,
 								 RhythmDBQueryModel *base,
 								 gboolean import_entries);
 
@@ -106,6 +115,8 @@ void			rhythmdb_query_model_add_entry		(RhythmDBQueryModel *model,
 gboolean		rhythmdb_query_model_remove_entry	(RhythmDBQueryModel *model,
 								 RhythmDBEntry *entry);
 
+void			rhythmdb_query_model_shuffle_entries 	(RhythmDBQueryModel *model);
+
 void			rhythmdb_query_model_move_entry 	(RhythmDBQueryModel *model,
 								 RhythmDBEntry *entry,
 								 gint index);
@@ -176,6 +187,10 @@ gint 			rhythmdb_query_model_double_ceiling_sort_func (RhythmDBEntry *a,
 gint 			rhythmdb_query_model_ulong_sort_func	(RhythmDBEntry *a,
 								 RhythmDBEntry *b,
 								 gpointer data);
+								 
+gint			rhythmdb_query_model_bitrate_sort_func  (RhythmDBEntry *a,
+								 RhythmDBEntry *b,
+								 gpointer data);
 
 gint 			rhythmdb_query_model_date_sort_func	(RhythmDBEntry *a,
 								 RhythmDBEntry *b,
