@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for RhythmDB tree-structured database implementation
- *
  *  Copyright (C) 2003 Colin Walters <walters@rhythmbox.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -8,6 +6,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -15,7 +21,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  */
 
@@ -24,7 +30,7 @@
 
 #include "rhythmdb-private.h"
 #include <glib-object.h>
-#include <glib/gatomic.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
@@ -37,6 +43,21 @@ G_BEGIN_DECLS
 
 typedef struct RhythmDBTreePrivate RhythmDBTreePrivate;
 
+/* RhythmDBEntry flags */
+enum {
+	RHYTHMDB_ENTRY_TREE_LOADING = RHYTHMDB_ENTRY_PRIVATE_FLAG_BASE,
+	RHYTHMDB_ENTRY_TREE_REMOVED = RHYTHMDB_ENTRY_PRIVATE_FLAG_BASE << 1,
+};
+
+typedef enum
+{
+	RHYTHMDB_TREE_ERROR_DATABASE_TOO_NEW,
+} RhythmTreeDBError;
+
+#define RHYTHMDB_TREE_ERROR (rhythmdb_tree_error_quark ())
+
+GQuark rhythmdb_tree_error_quark (void);
+
 typedef struct
 {
 	RhythmDB parent;
