@@ -1,6 +1,4 @@
- /*
- *  arch-tag: Header for RhythmDB - Rhythmbox backend queryable database
- *
+/*
  *  Copyright (C) 2003,2004 Colin Walters <walters@rhythmbox.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -8,6 +6,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -24,18 +30,18 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gio/gio.h>
 #include <stdarg.h>
 #include <libxml/tree.h>
 
-#include "config.h"
 #include "rb-refstring.h"
 #include "rb-string-value-map.h"
 #include "rhythmdb-query-results.h"
 
 G_BEGIN_DECLS
 
-struct RhythmDB_;
-typedef struct RhythmDB_ RhythmDB;
+typedef struct _RhythmDB RhythmDB;
+typedef struct _RhythmDBClass RhythmDBClass;
 
 #define RHYTHMDB_TYPE      (rhythmdb_get_type ())
 #define RHYTHMDB(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), RHYTHMDB_TYPE, RhythmDB))
@@ -54,7 +60,7 @@ GType rhythmdb_entry_get_type (void);
 typedef void (*RhythmDBEntryActionFunc) (RhythmDBEntry *entry, gpointer data);
 typedef char* (*RhythmDBEntryStringFunc) (RhythmDBEntry *entry, gpointer data);
 typedef gboolean (*RhythmDBEntryCanSyncFunc) (RhythmDB *db, RhythmDBEntry *entry, gpointer data);
-typedef void (*RhythmDBEntrySyncFunc) (RhythmDB *db, RhythmDBEntry *entry, GError **error, gpointer data);
+typedef void (*RhythmDBEntrySyncFunc) (RhythmDB *db, RhythmDBEntry *entry, GSList *changes, GError **error, gpointer data);
 
 GType rhythmdb_entry_category_get_type (void);
 #define RHYTHMDB_TYPE_ENTRY_CATEGORY (rhythmdb_entry_category_get_type ())
@@ -164,10 +170,10 @@ typedef enum
 	RHYTHMDB_PROP_LAST_PLAYED,
 	RHYTHMDB_PROP_BITRATE,
 	RHYTHMDB_PROP_DATE,
-	RHYTHMDB_PROP_TRACK_GAIN,
-	RHYTHMDB_PROP_TRACK_PEAK,
-	RHYTHMDB_PROP_ALBUM_GAIN,
-	RHYTHMDB_PROP_ALBUM_PEAK,
+	RHYTHMDB_PROP_TRACK_GAIN,			/* obsolete */
+	RHYTHMDB_PROP_TRACK_PEAK,			/* obsolete */
+	RHYTHMDB_PROP_ALBUM_GAIN,			/* obsolete */
+	RHYTHMDB_PROP_ALBUM_PEAK,			/* obsolete */
 	RHYTHMDB_PROP_MIMETYPE,
 	RHYTHMDB_PROP_TITLE_SORT_KEY,
 	RHYTHMDB_PROP_GENRE_SORT_KEY,
@@ -203,6 +209,12 @@ typedef enum
 	RHYTHMDB_PROP_MUSICBRAINZ_ALBUMID,
 	RHYTHMDB_PROP_MUSICBRAINZ_ALBUMARTISTID,
 	RHYTHMDB_PROP_ARTIST_SORTNAME,
+	RHYTHMDB_PROP_ALBUM_SORTNAME,
+
+	RHYTHMDB_PROP_ARTIST_SORTNAME_SORT_KEY,
+	RHYTHMDB_PROP_ARTIST_SORTNAME_FOLDED,
+	RHYTHMDB_PROP_ALBUM_SORTNAME_SORT_KEY,
+	RHYTHMDB_PROP_ALBUM_SORTNAME_FOLDED,
 
 	RHYTHMDB_NUM_PROPERTIES
 } RhythmDBPropType;
@@ -218,6 +230,10 @@ enum {
 #define RHYTHMDB_PROP_STREAM_SONG_TITLE		"rb:stream-song-title"
 #define RHYTHMDB_PROP_STREAM_SONG_ARTIST	"rb:stream-song-artist"
 #define RHYTHMDB_PROP_STREAM_SONG_ALBUM		"rb:stream-song-album"
+#define RHYTHMDB_PROP_COVER_ART			"rb:coverArt"
+#define RHYTHMDB_PROP_COVER_ART_URI		"rb:coverArt-uri"
+#define RHYTHMDB_PROP_ALBUM_ARTIST		"rb:album-artist"
+#define RHYTHMDB_PROP_ALBUM_ARTIST_SORTNAME	"rb:album-artist-sortname"
 
 GType rhythmdb_query_type_get_type (void);
 GType rhythmdb_prop_type_get_type (void);
@@ -258,16 +274,16 @@ typedef enum
 
 GQuark rhythmdb_error_quark (void);
 
-typedef struct RhythmDBPrivate RhythmDBPrivate;
+typedef struct _RhythmDBPrivate RhythmDBPrivate;
 
-struct RhythmDB_
+struct _RhythmDB
 {
 	GObject parent;
 
 	RhythmDBPrivate *priv;
 };
 
-typedef struct
+struct _RhythmDBClass
 {
 	GObjectClass parent;
 
@@ -288,7 +304,7 @@ typedef struct
 
 	/* virtual methods */
 
-	gboolean	(*impl_load)		(RhythmDB *db, gboolean *dead, GError **error);
+	gboolean	(*impl_load)		(RhythmDB *db, GCancellable *cancel, GError **error);
 	void		(*impl_save)		(RhythmDB *db);
 
 	void		(*impl_entry_new)	(RhythmDB *db, RhythmDBEntry *entry);
@@ -336,7 +352,7 @@ typedef struct
 							 RBRefString *keyword);
 	GList*		(*impl_entry_keywords_get)	(RhythmDB *db,
 							 RhythmDBEntry *entry);
-} RhythmDBClass;
+};
 
 GType		rhythmdb_get_type	(void);
 
@@ -371,6 +387,8 @@ void		rhythmdb_entry_set	(RhythmDB *db, RhythmDBEntry *entry,
 
 char *		rhythmdb_entry_get_playback_uri	(RhythmDBEntry *entry);
 
+gboolean	rhythmdb_entry_is_lossless (RhythmDBEntry *entry);
+
 gpointer	rhythmdb_entry_get_type_data (RhythmDBEntry *entry, guint expected_size);
 #define		RHYTHMDB_ENTRY_GET_TYPE_DATA(e,t)	((t*)rhythmdb_entry_get_type_data((e),sizeof(t)))
 
@@ -413,7 +431,7 @@ gboolean	rhythmdb_entry_keyword_has	(RhythmDB *db,
 GList* /*<RBRefString>*/ rhythmdb_entry_keywords_get	(RhythmDB *db,
 							 RhythmDBEntry *entry);
 
-/**
+/*
  * Returns a freshly allocated GtkTreeModel which represents the query.
  * The extended arguments alternate between RhythmDBQueryType args
  * and their values. Items are prioritized like algebraic expressions, and
@@ -455,9 +473,9 @@ RhythmDBQuery *	rhythmdb_query_copy			(RhythmDBQuery *array);
 void		rhythmdb_query_preprocess		(RhythmDB *db, RhythmDBQuery *query);
 
 void		rhythmdb_query_serialize		(RhythmDB *db, RhythmDBQuery *query,
-							 xmlNodePtr node);
+							 xmlNodePtr parent);
 
-RhythmDBQuery *	rhythmdb_query_deserialize		(RhythmDB *db, xmlNodePtr node);
+RhythmDBQuery *	rhythmdb_query_deserialize		(RhythmDB *db, xmlNodePtr parent);
 
 char *		rhythmdb_query_to_string		(RhythmDB *db, RhythmDBQuery *query);
 
