@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for object implementing main playback logic
- *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003,2004 Colin Walters <walters@verbum.org>
  *
@@ -122,7 +120,7 @@ gboolean		rb_shell_player_get_playing_time(RBShellPlayer *player,
 gboolean		rb_shell_player_set_playing_time(RBShellPlayer *player,
                                                          guint time,
                                                          GError **error);
-void			rb_shell_player_seek		(RBShellPlayer *player, long offset);
+void			rb_shell_player_seek		(RBShellPlayer *player, glong offset);
 long			rb_shell_player_get_playing_song_duration (RBShellPlayer *player);
 
 gboolean		rb_shell_player_get_playing	(RBShellPlayer *player,
