@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of preferences dialog object
  *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003 Colin Walters <walters@debian.org>
@@ -55,10 +53,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#if !GTK_CHECK_VERSION(2,14,0)
-#include <libgnome/gnome-help.h>
-#endif
-
 #include "rb-file-helpers.h"
 #include "rb-shell-preferences.h"
 #include "rb-source.h"
@@ -91,8 +85,6 @@ static void rb_shell_preferences_toolbar_style_cb (GtkComboBox *box,
 						   RBShellPreferences *preferences);
 static void rb_shell_preferences_player_backend_cb (GtkToggleButton *button,
 						    RBShellPreferences *preferences);
-static void rb_shell_preferences_album_crossfade_cb (GtkToggleButton *button,
-						     RBShellPreferences *preferences);
 static void rb_shell_preferences_transition_duration_cb (GtkRange *range,
 							 RBShellPreferences *preferences);
 static void rb_shell_preferences_network_buffer_size_cb (GtkRange *range,
@@ -125,7 +117,6 @@ struct RBShellPreferencesPrivate
 	GtkWidget *location_check;
 
 	GtkWidget *xfade_backend_check;
-	GtkWidget *album_crossfade_check;
 	GtkWidget *transition_duration;
 	GtkWidget *network_buffer_size;
 
@@ -156,14 +147,10 @@ help_cb (GtkWidget *widget,
 {
 	GError *error = NULL;
 
-#if GTK_CHECK_VERSION(2,14,0)
 	gtk_show_uri (gtk_widget_get_screen (widget),
 		      "ghelp:rhythmbox?prefs",
 		      gtk_get_current_event_time (),
 		      &error);
-#else
-	gnome_help_display ("rhythmbox.xml", "prefs", &error);
-#endif
 
 	if (error != NULL) {
 		rb_error_dialog (NULL,
@@ -178,6 +165,7 @@ static void
 rb_shell_preferences_init (RBShellPreferences *shell_preferences)
 {
 	GtkWidget *tmp;
+	GtkWidget *content_area;
 	GtkBuilder *builder;
 
 	shell_preferences->priv = RB_SHELL_PREFERENCES_GET_PRIVATE (shell_preferences);
@@ -208,11 +196,13 @@ rb_shell_preferences_init (RBShellPreferences *shell_preferences)
 	shell_preferences->priv->notebook = GTK_WIDGET (gtk_notebook_new ());
 	gtk_container_set_border_width (GTK_CONTAINER (shell_preferences->priv->notebook), 5);
 
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (shell_preferences)->vbox),
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (shell_preferences));
+
+	gtk_container_add (GTK_CONTAINER (content_area),
 			   shell_preferences->priv->notebook);
 
 	gtk_container_set_border_width (GTK_CONTAINER (shell_preferences), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (shell_preferences)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 	gtk_dialog_set_has_separator (GTK_DIALOG (shell_preferences), FALSE);
 
 	builder = rb_builder_load ("general-prefs.ui", shell_preferences);
@@ -277,14 +267,11 @@ rb_shell_preferences_init (RBShellPreferences *shell_preferences)
 	builder = rb_builder_load ("playback-prefs.ui", shell_preferences);
 
 	rb_builder_boldify_label (builder, "backend_label");
-	rb_builder_boldify_label (builder, "crossfade_type_label");
 	rb_builder_boldify_label (builder, "duration_label");
 	rb_builder_boldify_label (builder, "buffer_size_label");
 
 	shell_preferences->priv->xfade_backend_check =
 		GTK_WIDGET (gtk_builder_get_object (builder, "use_xfade_backend"));
-	shell_preferences->priv->album_crossfade_check =
-		GTK_WIDGET (gtk_builder_get_object (builder, "album_check"));
 	shell_preferences->priv->transition_duration =
 		GTK_WIDGET (gtk_builder_get_object (builder, "duration"));
 	shell_preferences->priv->network_buffer_size =
@@ -295,11 +282,6 @@ rb_shell_preferences_init (RBShellPreferences *shell_preferences)
 				 G_CALLBACK (rb_shell_preferences_player_backend_cb),
 				 shell_preferences, 0);
 
-	g_signal_connect_object (shell_preferences->priv->album_crossfade_check,
-				 "toggled",
-				 G_CALLBACK (rb_shell_preferences_album_crossfade_cb),
-				 shell_preferences, 0);
-
 	g_signal_connect_object (shell_preferences->priv->transition_duration,
 				 "value-changed",
 				 G_CALLBACK (rb_shell_preferences_transition_duration_cb),
@@ -608,9 +590,6 @@ rb_shell_preferences_sync (RBShellPreferences *shell_preferences)
 	b = eel_gconf_get_boolean (CONF_PLAYER_USE_XFADE_BACKEND);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (shell_preferences->priv->xfade_backend_check), b);
 
-	b = eel_gconf_get_boolean (CONF_PLAYER_TRANSITION_ALBUM_CHECK);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (shell_preferences->priv->album_crossfade_check), !b);
-
 	duration = eel_gconf_get_float (CONF_PLAYER_TRANSITION_TIME);
 	gtk_range_set_value (GTK_RANGE (shell_preferences->priv->transition_duration), duration);
 
@@ -665,7 +644,6 @@ update_playback_prefs_sensitivity (RBShellPreferences *preferences)
 
 	backend = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (preferences->priv->xfade_backend_check));
 
-	gtk_widget_set_sensitive (preferences->priv->album_crossfade_check, backend);
 	gtk_widget_set_sensitive (preferences->priv->transition_duration, backend);
 }
 
@@ -679,17 +657,6 @@ rb_shell_preferences_player_backend_cb (GtkToggleButton *button,
 			       gtk_toggle_button_get_active (button));
 }
 
-static void
-rb_shell_preferences_album_crossfade_cb (GtkToggleButton *button,
-					 RBShellPreferences *preferences)
-{
-	/* sense is inverted here because the wording sounded more natural
-	 * this way.  "[ ] Don't do x" sucks.
-	 */
-	eel_gconf_set_boolean (CONF_PLAYER_TRANSITION_ALBUM_CHECK,
-			       !gtk_toggle_button_get_active (button));
-}
-
 static void
 rb_shell_preferences_transition_duration_cb (GtkRange *range,
 					     RBShellPreferences *preferences)
