@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of browser-using source object
  *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003,2004 Colin Walters <walters@verbum.org>
@@ -68,9 +66,7 @@
 
 static void rb_browser_source_class_init (RBBrowserSourceClass *klass);
 static void rb_browser_source_init (RBBrowserSource *source);
-static GObject *rb_browser_source_constructor (GType type,
-					       guint n_construct_properties,
-					       GObjectConstructParam *construct_properties);
+static void rb_browser_source_constructed (GObject *object);
 static void rb_browser_source_dispose (GObject *object);
 static void rb_browser_source_finalize (GObject *object);
 static void rb_browser_source_set_property (GObject *object,
@@ -81,12 +77,9 @@ static void rb_browser_source_get_property (GObject *object,
 			                  guint prop_id,
 			                  GValue *value,
 			                  GParamSpec *pspec);
-static void rb_browser_source_cmd_choose_genre (GtkAction *action,
-						RBShell *shell);
-static void rb_browser_source_cmd_choose_artist (GtkAction *action,
-						 RBShell *shell);
-static void rb_browser_source_cmd_choose_album (GtkAction *action,
-						RBShell *shell);
+static void rb_browser_source_cmd_choose_genre (GtkAction *action, RBSource *source);
+static void rb_browser_source_cmd_choose_artist (GtkAction *action, RBSource *source);
+static void rb_browser_source_cmd_choose_album (GtkAction *action, RBSource *source);
 static void songs_view_sort_order_changed_cb (RBEntryView *view, RBBrowserSource *source);
 static void rb_browser_source_browser_changed_cb (RBLibraryBrowser *entry,
 						  GParamSpec *param,
@@ -200,7 +193,7 @@ rb_browser_source_class_init (RBBrowserSourceClass *klass)
 
 	object_class->dispose = rb_browser_source_dispose;
 	object_class->finalize = rb_browser_source_finalize;
-	object_class->constructor = rb_browser_source_constructor;
+	object_class->constructed = rb_browser_source_constructed;
 
 	object_class->set_property = rb_browser_source_set_property;
 	object_class->get_property = rb_browser_source_get_property;
@@ -341,10 +334,8 @@ default_show_entry_popup (RBBrowserSource *source)
 	_rb_source_show_popup (RB_SOURCE (source), "/BrowserSourceViewPopup");
 }
 
-static GObject *
-rb_browser_source_constructor (GType type,
-			       guint n_construct_properties,
-			       GObjectConstructParam *construct_properties)
+static void
+rb_browser_source_constructed (GObject *object)
 {
 	RBBrowserSource *source;
 	RBBrowserSourceClass *klass;
@@ -354,8 +345,9 @@ rb_browser_source_constructor (GType type,
 	char *paned_key;
 	RhythmDBEntryType entry_type;
 
-	source = RB_BROWSER_SOURCE (G_OBJECT_CLASS (rb_browser_source_parent_class)
-			->constructor (type, n_construct_properties, construct_properties));
+	RB_CHAIN_GOBJECT_METHOD (rb_browser_source_parent_class, constructed, object);
+
+	source = RB_BROWSER_SOURCE (object);
 
 	g_object_get (source,
 		      "shell", &shell,
@@ -366,9 +358,11 @@ rb_browser_source_constructor (GType type,
 
 	source->priv->action_group = _rb_source_register_action_group (RB_SOURCE (source),
 								       "BrowserSourceActions",
-								       rb_browser_source_actions,
-								       G_N_ELEMENTS (rb_browser_source_actions),
-								       shell);
+								       NULL, 0, NULL);
+	_rb_action_group_add_source_actions (source->priv->action_group,
+					     G_OBJECT (shell),
+					     rb_browser_source_actions,
+					     G_N_ELEMENTS (rb_browser_source_actions));
 
 	/* only add the actions if we haven't already */
 	if (gtk_action_group_get_action (source->priv->action_group,
@@ -487,8 +481,6 @@ rb_browser_source_constructor (GType type,
 	rb_browser_source_populate (source);
 
 	g_boxed_free (RHYTHMDB_TYPE_ENTRY_TYPE, entry_type);
-
-	return G_OBJECT (source);
 }
 
 static void
@@ -580,65 +572,49 @@ rb_browser_source_populate (RBBrowserSource *source)
 	g_boxed_free (RHYTHMDB_TYPE_ENTRY_TYPE, entry_type);
 }
 
-
 static void
-rb_browser_source_cmd_choose_genre (GtkAction *action,
-				    RBShell *shell)
+browse_property (RBBrowserSource *source, RhythmDBPropType prop)
 {
 	GList *props;
-	RBBrowserSource *source;
 	RBPropertyView *view;
 
+	props = rb_source_gather_selected_properties (RB_SOURCE (source), prop);
+	view = rb_library_browser_get_property_view (source->priv->browser, prop);
+	if (view) {
+		rb_property_view_set_selection (view, props);
+	}
+
+	rb_list_deep_free (props);
+}
+
+static void
+rb_browser_source_cmd_choose_genre (GtkAction *action, RBSource *source)
+{
 	rb_debug ("choosing genre");
 
-	g_object_get (G_OBJECT (shell), "selected-source", &source, NULL);
-	props = rb_source_gather_selected_properties (RB_SOURCE (source), RHYTHMDB_PROP_GENRE);
-	view = rb_library_browser_get_property_view (source->priv->browser, RHYTHMDB_PROP_GENRE);
-	if (view)
-		rb_property_view_set_selection (view, props);
-
-	rb_list_deep_free (props);
-	g_object_unref (source);
+	if (RB_IS_BROWSER_SOURCE (source)) {
+		browse_property (RB_BROWSER_SOURCE (source), RHYTHMDB_PROP_GENRE);
+	}
 }
 
 static void
-rb_browser_source_cmd_choose_artist (GtkAction *action,
-				     RBShell *shell)
+rb_browser_source_cmd_choose_artist (GtkAction *action, RBSource *source)
 {
-	GList *props;
-	RBBrowserSource *source;
-	RBPropertyView *view;
-
 	rb_debug ("choosing artist");
 
-	g_object_get (shell, "selected-source", &source, NULL);
-	props = rb_source_gather_selected_properties (RB_SOURCE (source), RHYTHMDB_PROP_ARTIST);
-	view = rb_library_browser_get_property_view (source->priv->browser, RHYTHMDB_PROP_ARTIST);
-	if (view)
-		rb_property_view_set_selection (view, props);
-
-	rb_list_deep_free (props);
-	g_object_unref (source);
+	if (RB_IS_BROWSER_SOURCE (source)) {
+		browse_property (RB_BROWSER_SOURCE (source), RHYTHMDB_PROP_ARTIST);
+	}
 }
 
 static void
-rb_browser_source_cmd_choose_album (GtkAction *action,
-				    RBShell *shell)
+rb_browser_source_cmd_choose_album (GtkAction *action, RBSource *source)
 {
-	GList *props;
-	RBBrowserSource *source;
-	RBPropertyView *view;
-
 	rb_debug ("choosing album");
 
-	g_object_get (G_OBJECT (shell), "selected-source", &source, NULL);
-	props = rb_source_gather_selected_properties (RB_SOURCE (source), RHYTHMDB_PROP_ALBUM);
-	view = rb_library_browser_get_property_view (source->priv->browser, RHYTHMDB_PROP_ALBUM);
-	if (view)
-		rb_property_view_set_selection (view, props);
-
-	rb_list_deep_free (props);
-	g_object_unref (source);
+	if (RB_IS_BROWSER_SOURCE (source)) {
+		browse_property (RB_BROWSER_SOURCE (source), RHYTHMDB_PROP_ALBUM);
+	}
 }
 
 static void
