@@ -6,6 +6,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -33,19 +41,21 @@ G_BEGIN_DECLS
 #define RB_IS_IMPORT_ERRORS_SOURCE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), RB_TYPE_IMPORT_ERRORS_SOURCE))
 #define RB_IMPORT_ERRORS_SOURCE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), RB_TYPE_IMPORT_ERRORS_SOURCE, RBImportErrorsSourceClass))
 
-typedef struct RBImportErrorsSourcePrivate RBImportErrorsSourcePrivate;
+typedef struct _RBImportErrorsSource RBImportErrorsSource;
+typedef struct _RBImportErrorsSourceClass RBImportErrorsSourceClass;
+typedef struct _RBImportErrorsSourcePrivate RBImportErrorsSourcePrivate;
 
-typedef struct
+struct _RBImportErrorsSource
 {
 	RBSource parent;
 
 	RBImportErrorsSourcePrivate *priv;
-} RBImportErrorsSource;
+};
 
-typedef struct
+struct _RBImportErrorsSourceClass
 {
 	RBSourceClass parent;
-} RBImportErrorsSourceClass;
+};
 
 GType		rb_import_errors_source_get_type		(void);
 
