@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of Internet Podcast source object
  *
  *  Copyright (C) 2005 Renato Araujo Oliveira Filho <renato.filho@indt.org.br>
  *
@@ -77,9 +75,7 @@ static void rb_podcast_source_class_init 		(RBPodcastSourceClass *klass);
 
 static void rb_podcast_source_init 			(RBPodcastSource *source);
 
-static GObject *rb_podcast_source_constructor 		(GType type,
-							 guint n_construct_properties,
-					      		 GObjectConstructParam *construct_properties);
+static void rb_podcast_source_constructed 		(GObject *object);
 
 static void rb_podcast_source_dispose 			(GObject *object);
 
@@ -259,6 +255,7 @@ static void impl_get_status				(RBSource *source,
 							 float *progress);
 static guint impl_want_uri				(RBSource *source, const char *uri);
 static gboolean impl_add_uri				(RBSource *source, const char *uri, const char *title, const char *genre);
+static char *impl_get_delete_action			(RBSource *source);
 
 #define CMD_PATH_SHOW_BROWSER "/commands/ShowBrowser"
 #define CMD_PATH_CURRENT_STATION "/commands/CurrentStation"
@@ -358,7 +355,7 @@ rb_podcast_source_class_init (RBPodcastSourceClass *klass)
 
 	object_class->dispose = rb_podcast_source_dispose;
 	object_class->finalize = rb_podcast_source_finalize;
-	object_class->constructor = rb_podcast_source_constructor;
+	object_class->constructed = rb_podcast_source_constructed;
 
 	object_class->set_property = rb_podcast_source_set_property;
 	object_class->get_property = rb_podcast_source_get_property;
@@ -384,6 +381,7 @@ rb_podcast_source_class_init (RBPodcastSourceClass *klass)
 	source_class->impl_get_status = impl_get_status;
 	source_class->impl_want_uri = impl_want_uri;
 	source_class->impl_add_uri = impl_add_uri;
+	source_class->impl_get_delete_action = impl_get_delete_action;
 
 	g_object_class_install_property (object_class,
 					 PROP_PODCAST_MANAGER,
@@ -493,13 +491,10 @@ rb_podcast_source_finalize (GObject *object)
 	G_OBJECT_CLASS (rb_podcast_source_parent_class)->finalize (object);
 }
 
-static GObject *
-rb_podcast_source_constructor (GType type,
-			       guint n_construct_properties,
-			       GObjectConstructParam *construct_properties)
+static void
+rb_podcast_source_constructed (GObject *object)
 {
 	RBPodcastSource *source;
-	RBPodcastSourceClass *klass;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 	RBShell *shell;
@@ -507,10 +502,8 @@ rb_podcast_source_constructor (GType type,
 	GPtrArray *query;
 	GtkAction *action;
 
-	klass = RB_PODCAST_SOURCE_CLASS (g_type_class_peek (RB_TYPE_PODCAST_SOURCE));
-
-	source = RB_PODCAST_SOURCE (G_OBJECT_CLASS (rb_podcast_source_parent_class)->
-			constructor (type, n_construct_properties, construct_properties));
+	RB_CHAIN_GOBJECT_METHOD (rb_podcast_source_parent_class, constructed, object);
+	source = RB_PODCAST_SOURCE (object);
 
 	g_object_get (source, "shell", &shell, NULL);
 	g_object_get (shell, "db", &source->priv->db, NULL);
@@ -785,8 +778,6 @@ rb_podcast_source_constructor (GType type,
 	rb_podcast_source_state_prefs_sync (source);
 
 	rb_podcast_source_do_query (source);
-
-	return G_OBJECT (source);
 }
 
 static void
@@ -945,12 +936,23 @@ impl_delete (RBSource *asource)
 	if (ret == GTK_RESPONSE_CANCEL || ret == GTK_RESPONSE_DELETE_EVENT)
 		return;
 
-	rb_podcast_manager_set_remove_files (source->priv->podcast_mgr,
-					     (ret == GTK_RESPONSE_YES));
-
 	entries = rb_entry_view_get_selected_entries (source->priv->posts);
 	for (l = entries; l != NULL; l = g_list_next (l)) {
-		rhythmdb_entry_delete (source->priv->db, l->data);
+		RhythmDBEntry *entry = l->data;
+
+		rb_podcast_manager_cancel_download (source->priv->podcast_mgr, entry);
+		if (ret == GTK_RESPONSE_YES) {
+			rb_podcast_manager_delete_download (source->priv->podcast_mgr, entry);
+		}
+
+		/* set podcast entries to invisible instead of deleted so they will
+		 * not reappear after the podcast has been updated
+		 */
+		GValue v = {0,};
+		g_value_init (&v, G_TYPE_BOOLEAN);
+		g_value_set_boolean (&v, TRUE);
+		rhythmdb_entry_set (source->priv->db, entry, RHYTHMDB_PROP_HIDDEN, &v);
+		g_value_unset (&v);
 	}
 
 	g_list_foreach (entries, (GFunc)rhythmdb_entry_unref, NULL);
@@ -1706,7 +1708,7 @@ impl_receive_drag (RBSource *asource, GtkSelectionData *selection_data)
 	GList *list, *i;
 	RBPodcastSource *source = RB_PODCAST_SOURCE (asource);
 
-	list = rb_uri_list_parse ((char *)selection_data->data);
+	list = rb_uri_list_parse ((const char *) gtk_selection_data_get_data (selection_data));
 
 	for (i = list; i != NULL; i = i->next) {
 		char *uri = NULL;
@@ -1717,7 +1719,7 @@ impl_receive_drag (RBSource *asource, GtkSelectionData *selection_data)
 			rb_podcast_source_add_feed (source, uri);
 		}
 		
-		if (selection_data->type == gdk_atom_intern ("_NETSCAPE_URL", FALSE)) {
+		if (gtk_selection_data_get_data_type (selection_data) == gdk_atom_intern ("_NETSCAPE_URL", FALSE)) {
 			i = i->next;
 		}
 	}
@@ -2151,3 +2153,8 @@ rb_podcast_source_pixbuf_clicked_cb (RBCellRendererPixbuf *renderer,
 	gtk_tree_path_free (path);
 }
 
+static char *
+impl_get_delete_action (RBSource *source)
+{
+	return g_strdup ("EditDelete");
+}
