@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for Internet Radio source object
- *
  *  Copyright (C) 2005 Renato Araujo Oliveira Filho <renato.filho@indt.org.br>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -8,7 +6,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -42,19 +40,22 @@ G_BEGIN_DECLS
 #define RB_IS_PODCAST_SOURCE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), RB_TYPE_PODCAST_SOURCE))
 #define RB_PODCAST_SOURCE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), RB_TYPE_PODCAST_SOURCE, RBPodcastSourceClass))
 
+typedef struct _RBPodcastSource RBPodcastSource;
+typedef struct _RBPodcastSourceClass RBPodcastSourceClass;
+
 typedef struct RBPodcastSourcePrivate RBPodcastSourcePrivate;
 
-typedef struct
+struct _RBPodcastSource
 {
 	RBSource parent;
 
 	RBPodcastSourcePrivate *priv;
-} RBPodcastSource;
+};
 
-typedef struct
+struct _RBPodcastSourceClass
 {
 	RBSourceClass parent;
-} RBPodcastSourceClass;
+};
 
 GType		rb_podcast_source_get_type	(void);
 RBSource *	rb_podcast_source_new		(RBShell *shell);
