@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for the abstract base class of all sources
- *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003 Colin Walters <walters@gnome.org>
  *
@@ -9,6 +7,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -23,12 +29,13 @@
 #ifndef __RB_SOURCE_H
 #define __RB_SOURCE_H
 
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkactiongroup.h>
+#include <gtk/gtk.h>
 
 #include "rb-source-group.h"
+#include "rb-source-search.h"
 #include "rb-entry-view.h"
 #include "rb-shell-preferences.h"
+#include "rhythmdb-import-job.h"
 
 G_BEGIN_DECLS
 
@@ -39,9 +46,24 @@ typedef enum {
 	RB_SOURCE_EOF_NEXT,
 } RBSourceEOFType;
 
+typedef enum {
+	RB_SOURCE_SEARCH_NONE,
+	RB_SOURCE_SEARCH_INCREMENTAL,
+	RB_SOURCE_SEARCH_EXPLICIT,
+} RBSourceSearchType;
+
+typedef struct _RBSource	RBSource;
+typedef struct _RBSourceClass	RBSourceClass;
+typedef struct _RBSourcePrivate	RBSourcePrivate;
+
+typedef void (*RBSourceActionCallback) (GtkAction *action, RBSource *source);
+
 GType rb_source_eof_type_get_type (void);
 #define RB_TYPE_SOURCE_EOF_TYPE	(rb_source_eof_type_get_type())
 
+GType rb_source_search_type_get_type (void);
+#define RB_TYPE_SOURCE_SEARCH_TYPE (rb_source_search_type_get_type())
+
 #define RB_TYPE_SOURCE         (rb_source_get_type ())
 #define RB_SOURCE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), RB_TYPE_SOURCE, RBSource))
 #define RB_SOURCE_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), RB_TYPE_SOURCE, RBSourceClass))
@@ -51,10 +73,6 @@ GType rb_source_eof_type_get_type (void);
 
 #define RB_SOURCE_ICON_SIZE	GTK_ICON_SIZE_LARGE_TOOLBAR
 
-typedef struct _RBSourceClass	RBSourceClass;
-typedef struct _RBSource		RBSource;
-typedef struct _RBSourcePrivate	RBSourcePrivate;
-
 typedef gboolean (*RBSourceFeatureFunc) (RBSource *source);
 typedef const char * (*RBSourceStringFunc) (RBSource *source);
 
@@ -85,9 +103,7 @@ struct _RBSourceClass
 
 	gboolean	(*impl_can_rename)	(RBSource *source);
 
-	gboolean	(*impl_can_search)	(RBSource *source);
-
-	void		(*impl_search)		(RBSource *source, const char *text);
+	void		(*impl_search)		(RBSource *source, RBSourceSearch *search, const char *cur_text, const char *new_text);
 	void		(*impl_reset_filters)	(RBSource *source);
 	GtkWidget *	(*impl_get_config_widget)(RBSource *source, RBShellPreferences *prefs);
 
@@ -110,6 +126,7 @@ struct _RBSourceClass
 	gboolean	(*impl_try_playlist)	(RBSource *source);
 	guint		(*impl_want_uri)	(RBSource *source, const char *uri);
 	gboolean	(*impl_add_uri)		(RBSource *source, const char *uri, const char *title, const char *genre);
+	gboolean	(*impl_uri_is_source)	(RBSource *source, const char *uri);
 
 	gboolean	(*impl_can_pause)	(RBSource *source);
 	RBSourceEOFType	(*impl_handle_eos)	(RBSource *source);
@@ -123,13 +140,14 @@ struct _RBSourceClass
 	void		(*impl_deactivate)	(RBSource *source);
 	GList *		(*impl_get_ui_actions)	(RBSource *source);
 	GList *		(*impl_get_search_actions) (RBSource *source);
+	char *		(*impl_get_delete_action) (RBSource *source);
 };
 
 GType		rb_source_get_type		(void);
 
 void		rb_source_notify_filter_changed	(RBSource *source);
 
-void		rb_source_notify_status_changed (RBSource *status);
+void		rb_source_notify_status_changed (RBSource *source);
 
 void		rb_source_update_play_statistics(RBSource *source, RhythmDB *db,
 						 RhythmDBEntry *entry);
@@ -148,9 +166,10 @@ GList *		rb_source_get_property_views	(RBSource *source);
 
 gboolean	rb_source_can_rename		(RBSource *source);
 
-gboolean	rb_source_can_search		(RBSource *source);
 void		rb_source_search		(RBSource *source,
-						 const char *text);
+						 RBSourceSearch *search,
+						 const char *cur_text,
+						 const char *new_text);
 
 void		rb_source_reset_filters		(RBSource *source);
 
@@ -175,6 +194,7 @@ void		rb_source_song_properties	(RBSource *source);
 
 gboolean	rb_source_try_playlist		(RBSource *source);
 guint		rb_source_want_uri		(RBSource *source, const char *uri);
+gboolean	rb_source_uri_is_source		(RBSource *source, const char *uri);
 gboolean	rb_source_add_uri		(RBSource *source, const char *uri, const char *title, const char *genre);
 
 gboolean	rb_source_can_pause		(RBSource *source);
@@ -191,6 +211,7 @@ void		rb_source_deactivate		(RBSource *source);
 
 GList *		rb_source_get_ui_actions	(RBSource *source);
 GList *		rb_source_get_search_actions	(RBSource *source);
+char *		rb_source_get_delete_action	(RBSource *source);
 
 GList *		rb_source_gather_selected_properties (RBSource *source, RhythmDBPropType prop);
 
@@ -205,6 +226,18 @@ GtkActionGroup *_rb_source_register_action_group (RBSource *source,
 						  GtkActionEntry *actions,
 						  int num_actions,
 						  gpointer user_data);
+void		_rb_action_group_add_source_actions (GtkActionGroup *group,
+						     GObject *shell,
+						     GtkActionEntry *actions,
+						     int num_actions);
+
+gboolean	_rb_source_check_entry_type	(RBSource *source,
+						 RhythmDBEntry *entry);
+
+void		_rb_source_set_import_status	(RBSource *source,
+						 RhythmDBImportJob *job,
+						 char **progress_text,
+						 float *progress);
 
 G_END_DECLS
 
