@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- * arch-tag: Implementation of main "Sources" display widget
  *
  * Copyright (C) 2003,2004 Colin Walters <walters@verbum.org>
  *
@@ -105,9 +103,7 @@ enum
 
 static void rb_sourcelist_class_init (RBSourceListClass *klass);
 static void rb_sourcelist_init (RBSourceList *sourcelist);
-static GObject * rb_sourcelist_constructor (GType type,
-					    guint n_construct_properties,
-					    GObjectConstructParam *construct_properties);
+static void rb_sourcelist_constructed (GObject *object);
 static void rb_sourcelist_finalize (GObject *object);
 static void rb_sourcelist_set_property (GObject *object,
 					guint prop_id,
@@ -141,7 +137,7 @@ rb_sourcelist_class_init (RBSourceListClass *class)
 	o_class = (GObjectClass *) class;
 	object_class = (GtkObjectClass *) class;
 
-	o_class->constructor = rb_sourcelist_constructor;
+	o_class->constructed = rb_sourcelist_constructed;
 	o_class->finalize = rb_sourcelist_finalize;
 	o_class->set_property = rb_sourcelist_set_property;
 	o_class->get_property = rb_sourcelist_get_property;
@@ -249,20 +245,16 @@ rb_sourcelist_class_init (RBSourceListClass *class)
 	g_type_class_add_private (class, sizeof (RBSourceListPrivate));
 }
 
-static GObject *
-rb_sourcelist_constructor (GType type,
-			   guint n_construct_properties,
-			   GObjectConstructParam *construct_properties)
+static void
+rb_sourcelist_constructed (GObject *object)
 {
 	RBSourceList *sourcelist;
 
-	sourcelist = RB_SOURCELIST (G_OBJECT_CLASS (rb_sourcelist_parent_class)
-			->constructor (type, n_construct_properties, construct_properties));
+	RB_CHAIN_GOBJECT_METHOD (rb_sourcelist_parent_class, constructed, object);
+	sourcelist = RB_SOURCELIST (object);
 
 	gtk_container_add (GTK_CONTAINER (sourcelist),
 			   sourcelist->priv->treeview);
-
-	return G_OBJECT (sourcelist);
 }
 
 static void
@@ -499,7 +491,8 @@ rb_sourcelist_expander_cell_data_func (GtkTreeViewColumn *column,
 		gboolean     row_expanded;
 
 		path = gtk_tree_model_get_path (model, iter);
-		row_expanded = gtk_tree_view_row_expanded (GTK_TREE_VIEW (column->tree_view), path);
+		row_expanded = gtk_tree_view_row_expanded (GTK_TREE_VIEW (gtk_tree_view_column_get_tree_view (column)),
+							   path);
 		gtk_tree_path_free (path);
 
 		g_object_set (cell,
@@ -777,19 +770,7 @@ rb_sourcelist_init (RBSourceList *sourcelist)
 						 NULL);
 	g_signal_connect_object (renderer, "edited", G_CALLBACK (source_name_edited_cb), sourcelist, 0);
 
-	if (g_object_class_find_property (G_OBJECT_GET_CLASS (sourcelist->priv->treeview), "show-expanders") != NULL) {
-		g_object_set (sourcelist->priv->treeview, "show-expanders", FALSE, NULL);
-	} else {
-		/* Hidden column for the normal treeview expander (gtk 2.8 compatibility) */
-		GtkTreeViewColumn *hidden;
-
-		hidden = gtk_tree_view_column_new ();
-
-		g_object_set (hidden, "visible", FALSE, NULL);
-
-		gtk_tree_view_append_column (GTK_TREE_VIEW (sourcelist->priv->treeview), hidden);
-		gtk_tree_view_set_expander_column (GTK_TREE_VIEW (sourcelist->priv->treeview), hidden);
-	}
+	g_object_set (sourcelist->priv->treeview, "show-expanders", FALSE, NULL);
 
 	/* Expander */
 	renderer = gossip_cell_renderer_expander_new ();
@@ -863,6 +844,8 @@ rb_sourcelist_get_property (GObject    *object,
  * rb_sourcelist_new:
  * @shell: the #RBShell instance
  *
+ * Creates the source list widget.
+ *
  * Return value: the source list widget.
  */
 GtkWidget *
