@@ -27,12 +27,12 @@
  *
  */
 
-/*
- * base class for streaming sources (internet radio, last.fm streams)
- * provides handling of:
- *  - buffering signals (done)
- *  - streaming song metadata (done)
- *  - possibly updating play count etc.?
+/**
+ * SECTION:rb-streaming-source
+ * @short_description: Base class for streaming sources such as internet radio
+ *
+ * This class provides handling of buffering signals and streaming song metadata
+ * common to different types of sources that play continuous streaming media.
  */
 
 #include "config.h"
@@ -59,8 +59,7 @@
 
 static void rb_streaming_source_class_init (RBStreamingSourceClass *klass);
 static void rb_streaming_source_init (RBStreamingSource *source);
-static GObject *rb_streaming_source_constructor (GType type, guint n_construct_properties,
-						 GObjectConstructParam *construct_properties);
+static void rb_streaming_source_constructed (GObject *object);
 static void rb_streaming_source_dispose (GObject *object);
 
 /* source methods */
@@ -83,7 +82,7 @@ static void extra_metadata_gather_cb (RhythmDB *db,
 				      RBStringValueMap *data,
 				      RBStreamingSource *source);
 
-struct RBStreamingSourcePrivate
+struct _RBStreamingSourcePrivate
 {
 	RhythmDB *db;
 
@@ -112,7 +111,7 @@ rb_streaming_source_class_init (RBStreamingSourceClass *klass)
 	RBSourceClass *source_class = RB_SOURCE_CLASS (klass);
 
 	object_class->dispose = rb_streaming_source_dispose;
-	object_class->constructor = rb_streaming_source_constructor;
+	object_class->constructed = rb_streaming_source_constructed;
 
 	source_class->impl_can_copy = (RBSourceFeatureFunc) rb_false_function;
 	source_class->impl_can_delete = (RBSourceFeatureFunc) rb_true_function;
@@ -151,19 +150,14 @@ rb_streaming_source_dispose (GObject *object)
 	G_OBJECT_CLASS (rb_streaming_source_parent_class)->dispose (object);
 }
 
-static GObject *
-rb_streaming_source_constructor (GType type,
-			      guint n_construct_properties,
-			      GObjectConstructParam *construct_properties)
+static void
+rb_streaming_source_constructed (GObject *object)
 {
 	RBStreamingSource *source;
-	RBStreamingSourceClass *klass;
 	RBShell *shell;
 
-	klass = RB_STREAMING_SOURCE_CLASS (g_type_class_peek (RB_TYPE_STREAMING_SOURCE));
-
-	source = RB_STREAMING_SOURCE (G_OBJECT_CLASS (rb_streaming_source_parent_class)
-			->constructor (type, n_construct_properties, construct_properties));
+	RB_CHAIN_GOBJECT_METHOD (rb_streaming_source_parent_class, constructed, object);
+	source = RB_STREAMING_SOURCE (object);
 
 	g_object_get (G_OBJECT (source), "shell", &shell, NULL);
 	g_object_get (G_OBJECT (shell),
@@ -198,8 +192,6 @@ rb_streaming_source_constructor (GType type,
 	g_signal_connect_object (source->priv->player, "playing-song-changed",
 				 G_CALLBACK (playing_entry_changed_cb),
 				 source, 0);
-
-	return G_OBJECT (source);
 }
 
 static RBSourceEOFType
@@ -208,6 +200,15 @@ impl_handle_eos (RBSource *asource)
 	return RB_SOURCE_EOF_RETRY;
 }
 
+/**
+ * rb_streaming_source_get_progress:
+ * @source: a #RBStreamingSource
+ * @text: returns buffering status text
+ * @progress: returns buffering progress fraction
+ *
+ * Provides status text and progress fraction suitable for use in
+ * a streaming source's @rb_source_get_status method.
+ */
 void
 rb_streaming_source_get_progress (RBStreamingSource *source, char **text, float *progress)
 {
@@ -353,9 +354,7 @@ emit_notification_cb (RBStreamingSource *source)
 	source->priv->emit_notify_id = 0;
 
 	g_object_get (G_OBJECT (source), "shell", &shell, NULL);
-	rb_shell_notify_playing_entry (shell,
-				       source->priv->playing_stream,
-				       FALSE);
+	rb_shell_do_notify (shell, FALSE, NULL);
 	g_object_unref (shell);
 
 	return FALSE;
@@ -393,6 +392,14 @@ set_streaming_metadata (RBStreamingSource *source,
 						      source);
 }
 
+/**
+ * rb_streaming_source_set_streaming_title:
+ * @source: a #RBStreamingSource
+ * @title: the new streaming song title
+ *
+ * Updates the streaming song title.  Call this when an updated
+ * streaming song title is received from the stream.
+ */
 void
 rb_streaming_source_set_streaming_title (RBStreamingSource *source,
 					 const char *title)
@@ -404,6 +411,14 @@ rb_streaming_source_set_streaming_title (RBStreamingSource *source,
 				title);
 }
 
+/**
+ * rb_streaming_source_set_streaming_artist:
+ * @source: a #RBStreamingSource
+ * @artist: the new streaming song artist name
+ *
+ * Updates the streaming song artist name.  Call this when an updated
+ * streaming song artist name is received from the stream.
+ */
 void
 rb_streaming_source_set_streaming_artist (RBStreamingSource *source,
 					  const char *artist)
@@ -415,6 +430,14 @@ rb_streaming_source_set_streaming_artist (RBStreamingSource *source,
 				artist);
 }
 
+/**
+ * rb_streaming_source_set_streaming_album:
+ * @source: a #RBStreamingSource
+ * @album: the new streaming song album name
+ *
+ * Updates the streaming song album name.  Call this when an updated
+ * streaming song album name is received from the stream.
+ */
 void
 rb_streaming_source_set_streaming_album (RBStreamingSource *source,
 					 const char *album)
@@ -481,4 +504,3 @@ playing_entry_changed_cb (RBShellPlayer *player,
 
 	g_object_unref (backend);
 }
-
