@@ -5,7 +5,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -245,18 +245,17 @@ main (int argc, char **argv)
 	g_thread_init (NULL);
 	rb_threads_init ();
 	gtk_set_locale ();
-	gtk_init (&argc, &argv);
-	gnome_vfs_init ();
 	rb_debug_init (TRUE);
 	rb_refstring_system_init ();
-	rb_file_helpers_init ();
-
-
-	GDK_THREADS_ENTER ();
+	rb_file_helpers_init (TRUE);
 
 	/* setup tests */
 	s = rhythmdb_query_model_suite ();
 	sr = srunner_create (s);
+
+	init_setup (sr, argc, argv);
+	init_once (FALSE);
+
 	srunner_run_all (sr, CK_NORMAL);
 	ret = srunner_ntests_failed (sr);
 	srunner_free (sr);
@@ -264,7 +263,6 @@ main (int argc, char **argv)
 
 	rb_file_helpers_shutdown ();
 	rb_refstring_system_shutdown ();
-	gnome_vfs_shutdown ();
 
 	rb_profile_end ("rhythmdb-query-model test suite");
 	return ret;
