@@ -5,7 +5,7 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  The Rhythmbox authors hereby grants permission for non-GPL compatible
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
  *  GStreamer plugins to be used and distributed together with GStreamer
  *  and Rhythmbox. This permission is above and beyond the permissions granted
  *  by the GPL license by which Rhythmbox is covered. If you modify this code
@@ -42,9 +42,6 @@
 #include "rhythmdb-tree.h"
 #include "rhythmdb-query-model.h"
 
-
-
-
 static void
 set_true (RhythmDBEntry *entry, gboolean *b)
 {
@@ -404,6 +401,111 @@ START_TEST (test_rhythmdb_deserialisation3)
 }
 END_TEST
 
+START_TEST (test_rhythmdb_podcast_upgrade)
+{
+	RhythmDBEntry *entry;
+	const char *mountpoint;
+
+	/* load db with old podcasts setups */
+	g_object_set (G_OBJECT (db), "name", SHARE_UNINSTALLED_DIR "/../tests/podcast-upgrade.xml", NULL);
+	set_waiting_signal (G_OBJECT (db), "load-complete");
+	rhythmdb_load (db);
+	wait_for_signal ();
+
+	entry = rhythmdb_entry_lookup_by_location (db, "file:///home/tester/Desktop/BBC%20Xtra/xtra_20080906-1226a.mp3");
+
+	fail_unless (entry != NULL, "entry missing");
+	fail_unless (rhythmdb_entry_get_entry_type (entry) == RHYTHMDB_ENTRY_TYPE_PODCAST_POST, "entry isn't a podcast");
+	mountpoint = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_MOUNTPOINT);
+
+	fail_unless (mountpoint != NULL, "no mountpoint for podcast");
+	fail_unless (strcmp (mountpoint, "http://downloads.bbc.co.uk/podcasts/worldservice/xtra/xtra_20080906-1226a.mp3") == 0, "wrong mountpoint for podcast");
+
+	entry = rhythmdb_entry_lookup_by_location (db, "http://downloads.bbc.co.uk/podcasts/worldservice/xtra/xtra_20080903-1217a.mp3");
+	fail_unless (entry != NULL, "entry not upgraded");
+	fail_unless (rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_MOUNTPOINT) == NULL, "wrong mountpoint for podcast");
+}
+END_TEST
+
+START_TEST (test_rhythmdb_modify_after_delete)
+{
+	RhythmDBEntry *entry;
+	GValue val = {0,};
+
+	entry = rhythmdb_entry_new (db, RHYTHMDB_ENTRY_TYPE_IGNORE, "file:///whee.ogg");
+	fail_unless (entry != NULL, "failed to create entry");
+
+	g_value_init (&val, G_TYPE_STRING);
+	g_value_set_static_string (&val, "Anything");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_GENRE, &val);
+	g_value_unset (&val);
+	
+	g_value_init (&val, G_TYPE_STRING);
+	g_value_set_static_string (&val, "Nothing");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_ARTIST, &val);
+	g_value_unset (&val);
+	
+	g_value_init (&val, G_TYPE_STRING);
+	g_value_set_static_string (&val, "Something");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_ALBUM, &val);
+	g_value_unset (&val);
+	
+	g_value_init (&val, G_TYPE_STRING);
+	g_value_set_static_string (&val, "Thing");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_TITLE, &val);
+	g_value_unset (&val);
+
+	rhythmdb_commit (db);
+	rhythmdb_entry_ref (entry);
+
+	rhythmdb_entry_delete (db, entry);
+	rhythmdb_commit (db);
+	
+	g_value_init (&val, G_TYPE_STRING);
+	g_value_set_static_string (&val, "Something Else");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_ALBUM, &val);
+	g_value_unset (&val);
+	
+	rhythmdb_commit (db);
+	rhythmdb_entry_unref (entry);
+}
+END_TEST
+
+static void
+commit_change_merge_cb (RhythmDB *db, RhythmDBEntry *entry, GSList *changes, gpointer ok)
+{
+	int expected = GPOINTER_TO_INT (ok);
+	fail_unless (g_slist_length (changes) == expected, "commit change lists merged");
+}
+
+START_TEST (test_rhythmdb_commit_change_merging)
+{
+	RhythmDBEntry *entry;
+	GValue val = {0,};
+
+	entry = rhythmdb_entry_new (db, RHYTHMDB_ENTRY_TYPE_IGNORE, "file:///whee.ogg");
+	fail_unless (entry != NULL, "failed to create entry");
+
+	rhythmdb_commit (db);
+
+	g_value_init (&val, G_TYPE_STRING);
+	g_value_set_static_string (&val, "Anything");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_GENRE, &val);
+	g_value_unset (&val);
+
+	rhythmdb_commit (db);
+
+	g_value_init (&val, G_TYPE_STRING);
+	g_value_set_static_string (&val, "Nothing");
+	rhythmdb_entry_set (db, entry, RHYTHMDB_PROP_ARTIST, &val);
+	g_value_unset (&val);
+
+	g_signal_connect (G_OBJECT (db), "entry-changed", G_CALLBACK (commit_change_merge_cb), GINT_TO_POINTER (2));
+	set_waiting_signal (G_OBJECT (db), "entry-changed");
+	rhythmdb_commit (db);
+	wait_for_signal ();
+}
+END_TEST
 
 static Suite *
 rhythmdb_suite (void)
@@ -432,6 +534,9 @@ rhythmdb_suite (void)
 	/*tcase_add_test (tc_chain, test_rhythmdb_serialisation);*/
 
 	/* tests for breakable bug fixes */
+	tcase_add_test (tc_chain, test_rhythmdb_podcast_upgrade);
+	tcase_add_test (tc_chain, test_rhythmdb_modify_after_delete);
+	tcase_add_test (tc_chain, test_rhythmdb_commit_change_merging);
 
 	return s;
 }
@@ -443,32 +548,30 @@ main (int argc, char **argv)
 	SRunner *sr;
 	Suite *s;
 
+	g_log_set_always_fatal (G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL);
+
 	/* init stuff */
 	rb_profile_start ("rhythmbox test suite");
 
 	g_thread_init (NULL);
 	rb_threads_init ();
-	gtk_set_locale ();
-	gtk_init (&argc, &argv);
-	gnome_vfs_init ();
 	rb_debug_init (TRUE);
 	rb_refstring_system_init ();
-	rb_file_helpers_init ();
-
-
-	GDK_THREADS_ENTER ();
+	rb_file_helpers_init (TRUE);
 
 	/* setup tests */
 	s = rhythmdb_suite ();
 	sr = srunner_create (s);
+
+	init_setup (sr, argc, argv);
+	init_once (FALSE);
+
 	srunner_run_all (sr, CK_NORMAL);
 	ret = srunner_ntests_failed (sr);
 	srunner_free (sr);
 
-
 	rb_file_helpers_shutdown ();
 	rb_refstring_system_shutdown ();
-	gnome_vfs_shutdown ();
 
 	rb_profile_end ("rhythmbox test suite");
 	return ret;
