@@ -1,7 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  arch-tag: Implementation of widget to display RhythmDB entries
- *
  *  Copyright (C) 2003 Colin Walters <walters@verbum.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -9,6 +7,14 @@
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
+ *  The Rhythmbox authors hereby grant permission for non-GPL compatible
+ *  GStreamer plugins to be used and distributed together with GStreamer
+ *  and Rhythmbox. This permission is above and beyond the permissions granted
+ *  by the GPL license by which Rhythmbox is covered. If you modify this code
+ *  you may extend this exception to your version of the code, but you are not
+ *  obligated to do so. If you do not wish to do so, delete this exception
+ *  statement from your version.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,6 +26,56 @@
  *
  */
 
+/**
+ * SECTION:rb-entry-view
+ * @short_description: a #GtkTreeView for displaying track listings
+ *
+ * This class provides a predefined set of columns for displaying the
+ * common set of #RhythmDBEntry properties, but also allows custom columns
+ * to be appended.  The 'playing' column is always created as the first
+ * column in the tree view, displaying a playing or paused image next to
+ * the currently playing entry, and also an error image next to entries for
+ * which a playback error message has been set.  Clicking on the error
+ * image opens a dialog displaying the full message.
+ *
+ * All columns added to entry view columns should be expandable, or have a fixed
+ * minimum width set.  Otherwise, the tree view must measure the contents of each
+ * row to assign sizes, which is very slow for large track lists.  All the predefined
+ * column types handle this correctly.
+ *
+ * The set of visible columns is controlled by a (single) GConf key, which
+ * contains a comma-delimited list of property names for which the associated
+ * columns are visible.  The entry view object tracks this automatically.
+ *
+ * If a GConf key for sorting is provided when constructing the entry view,
+ * it is watched and updated.  The sort settings consist of a column name
+ * and an order (ascending or descending).
+ */
+
+/**
+ * RBEntryViewColumn:
+ * @RB_ENTRY_VIEW_COL_TRACK_NUMBER: the track number column
+ * @RB_ENTRY_VIEW_COL_TITLE: the title column
+ * @RB_ENTRY_VIEW_COL_ARTIST: the artist column
+ * @RB_ENTRY_VIEW_COL_ALBUM: the album column
+ * @RB_ENTRY_VIEW_COL_GENRE: the genre column
+ * @RB_ENTRY_VIEW_COL_DURATION: the duration column
+ * @RB_ENTRY_VIEW_COL_QUALITY: the quality (bitrate) column
+ * @RB_ENTRY_VIEW_COL_RATING: the rating column
+ * @RB_ENTRY_VIEW_COL_PLAY_COUNT: the play count column
+ * @RB_ENTRY_VIEW_COL_YEAR: the year (release date) column
+ * @RB_ENTRY_VIEW_COL_LAST_PLAYED: the last played time column
+ * @RB_ENTRY_VIEW_COL_FIRST_SEEN: the first seen (imported) column
+ * @RB_ENTRY_VIEW_COL_LAST_SEEN: the last seen column
+ * @RB_ENTRY_VIEW_COL_LOCATION: the location column
+ * @RB_ENTRY_VIEW_COL_ERROR: the error column
+ *
+ * Predefined column types to use in #RBEntryView<!-- -->s.  Use
+ * #rb_entry_view_append_column to add these to an entry view.
+ * The predefined column names map directly to the #RhythmDBEntry properties
+ * the columns display.
+ */
+
 #include "config.h"
 
 #include <string.h>
@@ -29,7 +85,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <glib.h>
 
 #include "rb-tree-dnd.h"
 #include "rb-entry-view.h"
@@ -58,10 +114,12 @@ struct RBEntryViewColumnSortData
 	GDestroyNotify data_destroy;
 };
 
+/* GObject data item used to associate cell renderers with property IDs */
+#define CELL_PROPID_ITEM "rb-cell-propid"
+
 static void rb_entry_view_class_init (RBEntryViewClass *klass);
 static void rb_entry_view_init (RBEntryView *view);
-static GObject *rb_entry_view_constructor (GType type, guint n_construct_properties,
-					   GObjectConstructParam *construct_properties);
+static void rb_entry_view_constructed (GObject *object);
 static void rb_entry_view_dispose (GObject *object);
 static void rb_entry_view_finalize (GObject *object);
 static void rb_entry_view_sort_data_finalize (gpointer column,
@@ -231,13 +289,18 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 
 	object_class->dispose = rb_entry_view_dispose;
 	object_class->finalize = rb_entry_view_finalize;
-	object_class->constructor = rb_entry_view_constructor;
+	object_class->constructed = rb_entry_view_constructed;
 
 	object_class->set_property = rb_entry_view_set_property;
 	object_class->get_property = rb_entry_view_get_property;
 
 	widget_class->grab_focus = rb_entry_view_grab_focus;
 
+	/**
+	 * RBEntryView:db:
+	 *
+	 * #RhythmDB instance
+	 */
 	g_object_class_install_property (object_class,
 					 PROP_DB,
 					 g_param_spec_object ("db",
@@ -245,6 +308,11 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 							      "RhythmDB database",
 							      RHYTHMDB_TYPE,
 							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	/**
+	 * RBEntryView:shell-player:
+	 *
+	 * #RBShellPlayer instance
+	 */
 	g_object_class_install_property (object_class,
 					 PROP_SHELL_PLAYER,
 					 g_param_spec_object ("shell-player",
@@ -252,6 +320,11 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 							      "RBShellPlayer object",
 							      RB_TYPE_SHELL_PLAYER,
 							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	/**
+	 * RBEntryView:model:
+	 *
+	 * The #RhythmDBQueryModel backing the view
+	 */
 	g_object_class_install_property (object_class,
 					 PROP_MODEL,
 					 g_param_spec_object ("model",
@@ -259,13 +332,23 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 							      "RhythmDBQueryModel",
 							      RHYTHMDB_TYPE_QUERY_MODEL,
 							      G_PARAM_READWRITE));
+	/**
+	 * RBEntryView:sort-key:
+	 *
+	 * The GConf key that controls the sort order for the view
+	 */
 	g_object_class_install_property (object_class,
 					 PROP_SORTING_KEY,
 					 g_param_spec_string ("sort-key",
 							      "sorting key",
 							      "sorting key",
 							      "",
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+							      G_PARAM_READWRITE));
+	/**
+	 * RBEntryView:is-drag-source:
+	 *
+	 * If TRUE, the view acts as a data source for drag and drop operations.
+	 */
 	g_object_class_install_property (object_class,
 					 PROP_IS_DRAG_SOURCE,
 					 g_param_spec_boolean ("is-drag-source",
@@ -273,6 +356,11 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 							       "whether or not this is a drag source",
 							       FALSE,
 							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	/**
+	 * RBEntryView:is-drag-dest:
+	 *
+	 * If TRUE, the view acts as a destination for drag and drop operations.
+	 */
 	g_object_class_install_property (object_class,
 					 PROP_IS_DRAG_DEST,
 					 g_param_spec_boolean ("is-drag-dest",
@@ -280,6 +368,12 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 							       "whether or not this is a drag dest",
 							       FALSE,
 							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	/**
+	 * RBEntryView:playing-state:
+	 *
+	 * Determines the icon to show in the 'playing' column next to the current
+	 * playing entry.
+	 */
 	g_object_class_install_property (object_class,
 					 PROP_PLAYING_STATE,
 					 g_param_spec_int ("playing-state",
@@ -289,6 +383,13 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 							   RB_ENTRY_VIEW_PAUSED,
 							   RB_ENTRY_VIEW_NOT_PLAYING,
 							   G_PARAM_READWRITE));
+	/**
+	 * RBEntryView::entry-added
+	 * @view: the #RBEntryView
+	 * @entry: the #RhythmDBEntry that was added
+	 *
+	 * Emitted when an entry is added to the view
+	 */
 	rb_entry_view_signals[ENTRY_ADDED] =
 		g_signal_new ("entry-added",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -299,6 +400,13 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      RHYTHMDB_TYPE_ENTRY);
+	/**
+	 * RBEntryView::entry-deleted:
+	 * @view: the #RBEntryView
+	 * @entry: the #RhythmDBEntry that was removed
+	 *
+	 * Emitted when an entry has been removed from the view
+	 */
 	rb_entry_view_signals[ENTRY_DELETED] =
 		g_signal_new ("entry-deleted",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -309,6 +417,12 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      RHYTHMDB_TYPE_ENTRY);
+	/**
+	 * RBEntryView::entries-replaced:
+	 * @view: the #RBEntryView
+	 *
+	 * Emitted when the model backing the entry view is replaced.
+	 */
 	rb_entry_view_signals[ENTRIES_REPLACED] =
 		g_signal_new ("entries-replaced",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -318,6 +432,14 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
+	/**
+	 * RBEntryView::entry-activated:
+	 * @view: the #RBEntryView
+	 * @entry: the #RhythmDBEntry that was activated
+	 *
+	 * Emitted when an entry in the view is activated (by double clicking
+	 * or by various key presses)
+	 */
 	rb_entry_view_signals[ENTRY_ACTIVATED] =
 		g_signal_new ("entry-activated",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -328,6 +450,12 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      RHYTHMDB_TYPE_ENTRY);
+	/**
+	 * RBEntryView::selection-changed:
+	 * @view: the #RBEntryView
+	 *
+	 * Emitted when the set of selected entries changes
+	 */
 	rb_entry_view_signals[SELECTION_CHANGED] =
 		g_signal_new ("selection-changed",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -337,6 +465,18 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
+	/**
+	 * RBEntryView::show-popup
+	 * @view: the #RBEntryView
+	 * @over_entry: if TRUE, the popup request was made while pointing
+	 * at an entry in the view
+	 *
+	 * Emitted when the user performs an action that should result in a
+	 * popup menu appearing.  If the action was a mouse button click, 
+	 * over_entry is FALSE if the mouse pointer was in the blank space after
+	 * the last row in the view.  If the action was a key press, over_entry
+	 * is FALSE if no rows in the view are selected.
+	 */
 	rb_entry_view_signals[SHOW_POPUP] =
 		g_signal_new ("show_popup",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -347,6 +487,14 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
+	/**
+	 * RBEntryView::have-selection-changed:
+	 * @view: the #RBEntryView
+	 * @have_selection: TRUE if one or more rows are selected
+	 *
+	 * Emitted when the user first selects a row, or when no rows are selected
+	 * any more.
+	 */
 	rb_entry_view_signals[HAVE_SEL_CHANGED] =
 		g_signal_new ("have_selection_changed",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -357,6 +505,12 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
+	/**
+	 * RBEntryView::sort-order-changed:
+	 * @view: the #RBEntryView
+	 *
+	 * Emitted when the user changes the sort order for the view
+	 */
 	rb_entry_view_signals[SORT_ORDER_CHANGED] =
 		g_signal_new ("sort-order-changed",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -382,17 +536,17 @@ rb_entry_view_init (RBEntryView *view)
 	icon_theme = gtk_icon_theme_get_default ();
 
 	view->priv->playing_pixbuf = gtk_icon_theme_load_icon (icon_theme,
-                                   			       "stock_media-play",
+                                   			       "media-playback-start",
                                    			       16,
                                    			       0,
                                    			       NULL);
 	view->priv->paused_pixbuf = gtk_icon_theme_load_icon (icon_theme,
-                                   			      "stock_media-pause",
+                                   			      "media-playback-pause",
                                    			      16,
                                    			      0,
                                    			      NULL);
 	view->priv->error_pixbuf = gtk_icon_theme_load_icon (icon_theme,
-                                   			     "stock_dialog-error",
+                                   			     "dialog-error",
                                    			     16,
                                    			     0,
                                    			     NULL);
@@ -450,6 +604,12 @@ rb_entry_view_dispose (GObject *object)
 	}
 
 	if (view->priv->model != NULL) {
+		/* remove the model from the treeview so
+		 * atk-bridge doesn't have to emit deletion events
+		 * for each cell in the view.
+		 */
+		gtk_tree_view_set_model (GTK_TREE_VIEW (view->priv->treeview), NULL);
+
 		g_object_unref (view->priv->model);
 		view->priv->model = NULL;
 	}
@@ -573,6 +733,7 @@ rb_entry_view_set_property (GObject *object,
 			    const GValue *value,
 			    GParamSpec *pspec)
 {
+	char *old_sorting_key;
 	RBEntryView *view = RB_ENTRY_VIEW (object);
 
 	switch (prop_id) {
@@ -583,8 +744,42 @@ rb_entry_view_set_property (GObject *object,
 		rb_entry_view_set_shell_player_internal (view, g_value_get_object (value));
 		break;
 	case PROP_SORTING_KEY:
-		g_free (view->priv->sorting_key);
+		/* Remove notification on old key, if any. */
+		if (view->priv->sorting_key) {
+			eel_gconf_notification_remove (view->priv->sorting_gconf_notification_id);
+			view->priv->sorting_gconf_notification_id = 0;
+		}
+
+		old_sorting_key = view->priv->sorting_key;
 		view->priv->sorting_key = g_value_dup_string (value);
+
+		if (view->priv->sorting_key && view->priv->sorting_key[0] != '\0') {
+			char *new_sorting_type;
+
+			/* Set up notification on the new key. */
+			view->priv->sorting_gconf_notification_id =
+				eel_gconf_notification_add (view->priv->sorting_key,
+							    rb_entry_view_sort_key_changed_cb,
+							    view);
+
+			rb_entry_view_set_columns_clickable (view, TRUE);
+
+			/* If there was already a sorting key, assume this is a rename. */
+			if (old_sorting_key && old_sorting_key[0] != '\0') {
+				/* Propagate existing sort order into the new GConf key. */
+				eel_gconf_set_string (view->priv->sorting_key,
+						      rb_entry_view_get_sorting_type (view));
+
+				eel_gconf_unset (old_sorting_key);
+			}
+
+			/* Synchronise UI sorting order with the new key. */
+			new_sorting_type = eel_gconf_get_string (view->priv->sorting_key);
+			rb_entry_view_set_sorting_type (view, new_sorting_type);
+			g_free (new_sorting_type);
+		}
+
+		g_free (old_sorting_key);
 		break;
 	case PROP_MODEL:
 		rb_entry_view_set_model_internal (view, g_value_get_object (value));
@@ -645,6 +840,23 @@ rb_entry_view_get_property (GObject *object,
 	}
 }
 
+/**
+ * rb_entry_view_new:
+ * @db: the #RhythmDB instance
+ * @shell_player: the #RBShellPlayer instance
+ * @sort_key: the GConf key controlling the sort order for the view
+ * @is_drag_source: if TRUE, the view should act as a drag and drop data source
+ * @is_drag_dest: if TRUE, the view should act as a drag and drop destination
+ *
+ * Creates a new entry view.  If it makes sense to allow the user to drag entries
+ * from this entry view to other sources, @is_drag_source should be TRUE.  If it
+ * makes sense to allow the user to drag entries from other sources to this view,
+ * @is_drag_dest should be TRUE.  Drag and drop in this sense is used for two purposes:
+ * to transfer tracks between the filesystem and removable devices, and to add tracks
+ * to playlists.
+ *
+ * Return value: the new entry view
+ */
 RBEntryView *
 rb_entry_view_new (RhythmDB *db,
 		   GObject *shell_player,
@@ -658,7 +870,7 @@ rb_entry_view_new (RhythmDB *db,
 					   "hadjustment", NULL,
 					   "vadjustment", NULL,
 					   "hscrollbar_policy", GTK_POLICY_AUTOMATIC,
-					   "vscrollbar_policy", GTK_POLICY_ALWAYS,
+					   "vscrollbar_policy", GTK_POLICY_AUTOMATIC,
 					   "shadow_type", GTK_SHADOW_IN,
 					   "db", db,
 					   "shell-player", RB_SHELL_PLAYER (shell_player),
@@ -672,6 +884,13 @@ rb_entry_view_new (RhythmDB *db,
 	return view;
 }
 
+/**
+ * rb_entry_view_set_model:
+ * @view: the #RBEntryView
+ * @model: the new #RhythmDBQueryModel to use for the view
+ *
+ * Replaces the model backing the entry view.
+ */
 void
 rb_entry_view_set_model (RBEntryView *view,
 			 RhythmDBQueryModel *model)
@@ -848,18 +1067,21 @@ rb_entry_view_quality_cell_data_func (GtkTreeViewColumn *column,
 				      struct RBEntryViewCellDataFuncData *data)
 {
 	RhythmDBEntry *entry;
-	guint bitrate;
+	gulong bitrate;
 
 	entry = rhythmdb_query_model_iter_to_entry (data->view->priv->model, iter);
+	bitrate = rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_BITRATE);
 
-	bitrate = rhythmdb_entry_get_ulong (entry, data->propid);
-
-	if (bitrate > 0) {
-		char *s = g_strdup_printf (_("%u kbps"), (guint)bitrate);
+	if (rhythmdb_entry_is_lossless (entry)) {
+		g_object_set (renderer, "text", _("Lossless"), NULL);
+	} else if (bitrate == 0) {
+		g_object_set (renderer, "text", _("Unknown"), NULL);
+	} else {
+		char *s;
+	       
+		s = g_strdup_printf (_("%lu kbps"), bitrate);
 		g_object_set (renderer, "text", s, NULL);
 		g_free (s);
-	} else {
-		g_object_set (renderer, "text", _("Unknown"), NULL);
 	}
 
 	rhythmdb_entry_unref (entry);
@@ -879,7 +1101,7 @@ rb_entry_view_location_cell_data_func (GtkTreeViewColumn *column,
 	entry = rhythmdb_query_model_iter_to_entry (data->view->priv->model, iter);
 
 	location = rhythmdb_entry_get_string (entry, data->propid);
-	str = gnome_vfs_unescape_string_for_display (location);
+	str = g_uri_unescape_string (location, NULL);
 
 	g_object_set (renderer, "text", str, NULL);
 	g_free (str);
@@ -945,6 +1167,16 @@ rb_entry_view_sync_sorting (RBEntryView *view)
 	g_free (column_name);
 }
 
+/**
+ * rb_entry_view_get_sorting_type:
+ * @view: an #RBEntryView
+ *
+ * Constructs a string that describes the sort settings for the entry view.
+ * This consists of a column name and an order ('ascending' or 'descending')
+ * separated by a comma.
+ *
+ * Return value: sort order description (must be freed)
+ */
 char *
 rb_entry_view_get_sorting_type (RBEntryView *view)
 {
@@ -971,6 +1203,15 @@ rb_entry_view_get_sorting_type (RBEntryView *view)
 	return sorttype;
 }
 
+/**
+ * rb_entry_view_set_sorting_type:
+ * @view: a #RBEntryView
+ * @sorttype: sort order description
+ *
+ * Changes the sort order for the entry view.  The sort order
+ * description must be a column name, followed by a comma, followed
+ * by an order description ('ascending' or 'descending').
+ */
 void
 rb_entry_view_set_sorting_type (RBEntryView *view,
 				const char *sorttype)
@@ -1001,6 +1242,14 @@ rb_entry_view_set_sorting_type (RBEntryView *view,
 	rb_entry_view_sync_sorting (view);
 }
 
+/**
+ * rb_entry_view_get_sorting_order:
+ * @view: a #RBEntryView
+ * @column_name: returns the sort column name
+ * @sort_order: returns the sort ordering as a #GtkSortType value
+ *
+ * Retrieves the sort settings for the view.
+ */
 void
 rb_entry_view_get_sorting_order (RBEntryView *view,
 				 char **column_name,
@@ -1017,6 +1266,14 @@ rb_entry_view_get_sorting_order (RBEntryView *view,
 	}
 }
 
+/**
+ * rb_entry_view_set_sorting_order:
+ * @view: a #RBEntryView
+ * @column_name: name of the column to sort on
+ * @sort_order: order to sort in, as a #GtkSortOrder
+ *
+ * Sets the sort order for the entry view.
+ */
 void
 rb_entry_view_set_sorting_order (RBEntryView *view,
 				 const char *column_name,
@@ -1058,6 +1315,135 @@ rb_entry_view_column_clicked_cb (GtkTreeViewColumn *column, RBEntryView *view)
 		eel_gconf_set_string (view->priv->sorting_key, rb_entry_view_get_sorting_type(view));
 }
 
+/**
+ * rb_entry_view_get_column:
+ * @view: a #RBEntryView
+ * @coltype: type of column to retrieve
+ *
+ * Retrieves a predefined column from the entry view.  This can be used
+ * to insert additional cell renderers into the column.
+ *
+ * Return value: a #GtkTreeViewColumn instance, or NULL
+ */
+GtkTreeViewColumn *
+rb_entry_view_get_column (RBEntryView *view, RBEntryViewColumn coltype)
+{
+	RhythmDBPropType propid;
+
+	/* convert column type to property ID */
+	switch (coltype) {
+	case RB_ENTRY_VIEW_COL_TRACK_NUMBER:
+		propid = RHYTHMDB_PROP_TRACK_NUMBER;
+		break;
+	case RB_ENTRY_VIEW_COL_TITLE:
+		propid = RHYTHMDB_PROP_TITLE;
+		break;
+	case RB_ENTRY_VIEW_COL_ARTIST:
+		propid = RHYTHMDB_PROP_ARTIST;
+		break;
+	case RB_ENTRY_VIEW_COL_ALBUM:
+		propid = RHYTHMDB_PROP_ALBUM;
+		break;
+	case RB_ENTRY_VIEW_COL_GENRE:
+		propid = RHYTHMDB_PROP_GENRE;
+		break;
+	case RB_ENTRY_VIEW_COL_DURATION:
+		propid = RHYTHMDB_PROP_DURATION;
+		break;
+	case RB_ENTRY_VIEW_COL_YEAR:
+		propid = RHYTHMDB_PROP_DATE;
+		break;
+	case RB_ENTRY_VIEW_COL_QUALITY:
+		propid = RHYTHMDB_PROP_BITRATE;
+		break;
+	case RB_ENTRY_VIEW_COL_RATING:
+		propid = RHYTHMDB_PROP_RATING;
+		break;
+	case RB_ENTRY_VIEW_COL_PLAY_COUNT:
+		propid = RHYTHMDB_PROP_PLAY_COUNT;
+		break;
+	case RB_ENTRY_VIEW_COL_LAST_PLAYED:
+		propid = RHYTHMDB_PROP_LAST_PLAYED;
+		break;
+	case RB_ENTRY_VIEW_COL_FIRST_SEEN:
+		propid = RHYTHMDB_PROP_FIRST_SEEN;
+		break;
+	case RB_ENTRY_VIEW_COL_LAST_SEEN:
+		propid = RHYTHMDB_PROP_LAST_SEEN;
+		break;
+	case RB_ENTRY_VIEW_COL_LOCATION:
+		propid = RHYTHMDB_PROP_LOCATION;
+		break;
+	case RB_ENTRY_VIEW_COL_ERROR:
+		propid = RHYTHMDB_PROP_PLAYBACK_ERROR;
+		break;
+	default:
+		g_assert_not_reached ();
+		propid = -1;
+		break;
+	}
+
+	/* find the column */
+	return (GtkTreeViewColumn *)g_hash_table_lookup (view->priv->propid_column_map, GINT_TO_POINTER (propid));
+}
+
+static void
+rb_entry_view_cell_edited_cb (GtkCellRendererText *renderer,
+			      char *path_str,
+			      char *new_text,
+			      RBEntryView *view)
+{
+	RhythmDBPropType propid;
+	RhythmDBEntry *entry;
+	GValue value = {0,};
+	GtkTreePath *path;
+
+	/* get the property corresponding to the cell, filter out properties we can't edit */
+	propid = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (renderer), CELL_PROPID_ITEM));
+	switch (propid) {
+	case RHYTHMDB_PROP_TITLE:
+	case RHYTHMDB_PROP_GENRE:
+	case RHYTHMDB_PROP_ARTIST:
+	case RHYTHMDB_PROP_ALBUM:
+	case RHYTHMDB_PROP_ARTIST_SORTNAME:
+	case RHYTHMDB_PROP_ALBUM_SORTNAME:
+		break;
+
+	default:
+		rb_debug ("can't edit property %s", rhythmdb_nice_elt_name_from_propid (view->priv->db, propid));
+		return;
+	}
+
+	/* find entry */
+	path = gtk_tree_path_new_from_string (path_str);
+	entry = rhythmdb_query_model_tree_path_to_entry (view->priv->model, path);
+	gtk_tree_path_free (path);
+
+	if (entry != NULL) {
+		/* update it */
+		g_value_init (&value, G_TYPE_STRING);
+		g_value_set_string (&value, new_text);
+		rhythmdb_entry_set (view->priv->db, entry, propid, &value);
+		g_value_unset (&value);
+
+		rhythmdb_commit (view->priv->db);
+		rhythmdb_entry_unref (entry);
+	}
+}
+
+
+/**
+ * rb_entry_view_append_column:
+ * @view: a #RBEntryView
+ * @coltype: type of column to append
+ * @always_visible: if TRUE, ignore the user's column visibility settings
+ *
+ * Appends a predefined column type to the set of columns already present
+ * in the entry view.  If @always_visible is TRUE, the column will ignore
+ * the user's coulmn visibility settings and will always be visible.
+ * This should only be used when it is vital for the purpose of the 
+ * source that the column be visible.
+ */
 void
 rb_entry_view_append_column (RBEntryView *view,
 			     RBEntryViewColumn coltype,
@@ -1068,7 +1454,7 @@ rb_entry_view_append_column (RBEntryView *view,
 	struct RBEntryViewCellDataFuncData *cell_data;
 	const char *title = NULL;
 	const char *key = NULL;
-	const char *strings[4] = {0};
+	const char *strings[5] = {0};
 	GtkTreeCellDataFunc cell_data_func = NULL;
 	GCompareDataFunc sort_func = NULL;
 	RhythmDBPropType propid;
@@ -1162,12 +1548,13 @@ rb_entry_view_append_column (RBEntryView *view,
 		cell_data->propid = propid;
 		cell_data_func = (GtkTreeCellDataFunc) rb_entry_view_quality_cell_data_func;
 		sort_propid = cell_data->propid;
-		sort_func = (GCompareDataFunc) rhythmdb_query_model_ulong_sort_func;
+		sort_func = (GCompareDataFunc) rhythmdb_query_model_bitrate_sort_func;
 		title = _("Quality");
 		key = "Quality";
 		strings[0] = title;
 		strings[1] = _("000 kbps");
 		strings[2] = _("Unknown");
+		strings[3] = _("Lossless");
 		break;
 	case RB_ENTRY_VIEW_COL_RATING:
 		propid = RHYTHMDB_PROP_RATING;
@@ -1270,6 +1657,11 @@ rb_entry_view_append_column (RBEntryView *view,
 		gtk_tree_view_column_pack_start (column, renderer, TRUE);
 		gtk_tree_view_column_set_cell_data_func (column, renderer,
 							 cell_data_func, cell_data, g_free);
+
+		g_object_set_data (G_OBJECT (renderer), CELL_PROPID_ITEM, GINT_TO_POINTER (propid));
+		g_signal_connect_object (renderer, "edited",
+					 G_CALLBACK (rb_entry_view_cell_edited_cb),
+					 view, 0);
 	} else {
 		g_free (cell_data);
 	}
@@ -1304,6 +1696,18 @@ rb_entry_view_append_column (RBEntryView *view,
 	rb_entry_view_append_column_custom (view, column, title, key, sort_func, GINT_TO_POINTER (sort_propid), NULL);
 }
 
+/**
+ * rb_entry_view_append_column_custom:
+ * @view: a #RBEntryView
+ * @column: a #GtkTreeViewColumn to append
+ * @title: title for the column (translated)
+ * @key: sort key for the column (not translated)
+ * @sort_func: comparison function to use for sorting on the column
+ * @data: data to pass to the sort function
+ * @data_destroy: function to use to destroy the sort data
+ *
+ * Appends a custom column to the entry view.  
+ */
 void
 rb_entry_view_append_column_custom (RBEntryView *view,
 				    GtkTreeViewColumn *column,
@@ -1316,6 +1720,19 @@ rb_entry_view_append_column_custom (RBEntryView *view,
 	rb_entry_view_insert_column_custom (view, column, title, key, sort_func, data, data_destroy, -1);
 }
 
+/**
+ * rb_entry_view_insert_column_custom:
+ * @view: a #RBEntryView
+ * @column: a #GtkTreeViewColumn to append
+ * @title: title for the column (translated)
+ * @key: sort key for the column (not translated)
+ * @sort_func: comparison function to use for sorting on the column
+ * @data: data to pass to the sort function
+ * @data_destroy: function to use to destroy the sort data
+ * @position: position at which to insert the column (-1 to insert at the end)
+ *
+ * Inserts a custom column at the specified position.
+ */
 void
 rb_entry_view_insert_column_custom (RBEntryView *view,
 				    GtkTreeViewColumn *column,
@@ -1331,9 +1748,6 @@ rb_entry_view_insert_column_custom (RBEntryView *view,
 	gtk_tree_view_column_set_title (column, title);
 	gtk_tree_view_column_set_reorderable (column, FALSE);
 
-	g_signal_connect_object (column, "clicked",
-				 G_CALLBACK (rb_entry_view_column_clicked_cb),
-				 view, 0);
 
 	g_object_set_data_full (G_OBJECT (column), "rb-entry-view-key",
 				g_strdup (key), g_free);
@@ -1348,6 +1762,10 @@ rb_entry_view_insert_column_custom (RBEntryView *view,
 		sortdata->data = data;
 		sortdata->data_destroy = data_destroy;
 		g_hash_table_insert (view->priv->column_sort_data_map, column, sortdata);
+
+		g_signal_connect_object (column, "clicked",
+					 G_CALLBACK (rb_entry_view_column_clicked_cb),
+					 view, 0);
 	}
 	g_hash_table_insert (view->priv->column_key_map, g_strdup (key), column);
 
@@ -1355,6 +1773,14 @@ rb_entry_view_insert_column_custom (RBEntryView *view,
 	rb_entry_view_sync_sorting (view);
 }
 
+/**
+ * rb_entry_view_set_columns_clickable:
+ * @view: a #RBEntryView
+ * @clickable: if TRUE, sortable columns will be made clickable
+ *
+ * Makes the headers for sortable columns (those for which a sort function was
+ * provided) clickable, so the user can set the sort order.
+ */
 void
 rb_entry_view_set_columns_clickable (RBEntryView *view,
 				     gboolean clickable)
@@ -1371,17 +1797,14 @@ rb_entry_view_set_columns_clickable (RBEntryView *view,
 	g_list_free (columns);
 }
 
-static GObject *
-rb_entry_view_constructor (GType type,
-			   guint n_construct_properties,
-			   GObjectConstructParam *construct_properties)
+static void
+rb_entry_view_constructed (GObject *object)
 {
 	RBEntryView *view;
-	RBEntryViewClass *klass;
-	klass = RB_ENTRY_VIEW_CLASS (g_type_class_peek (RB_TYPE_ENTRY_VIEW));
 
-	view = RB_ENTRY_VIEW (G_OBJECT_CLASS (rb_entry_view_parent_class)
-			->constructor (type, n_construct_properties, construct_properties));
+	RB_CHAIN_GOBJECT_METHOD (rb_entry_view_parent_class, constructed, object);
+
+	view = RB_ENTRY_VIEW (object);
 
 	view->priv->treeview = GTK_WIDGET (gtk_tree_view_new ());
 	gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (view->priv->treeview), TRUE);
@@ -1436,13 +1859,10 @@ rb_entry_view_constructor (GType type,
 
 	{
 		GtkTreeViewColumn *column;
-		GtkTooltips *tooltip;
 		GtkCellRenderer *renderer;
 		GtkWidget *image_widget;
 		gint width;
 
-		tooltip = gtk_tooltips_new ();
-
 		/* Playing icon column */
 		column = GTK_TREE_VIEW_COLUMN (gtk_tree_view_column_new ());
 		renderer = rb_cell_renderer_pixbuf_new ();
@@ -1453,7 +1873,7 @@ rb_entry_view_constructor (GType type,
 							 view,
 							 NULL);
 
-		image_widget = gtk_image_new_from_icon_name ("stock_volume-max", GTK_ICON_SIZE_MENU);
+		image_widget = gtk_image_new_from_icon_name ("audio-volume-high", GTK_ICON_SIZE_MENU);
 		gtk_tree_view_column_set_widget (column, image_widget);
 		gtk_widget_show (image_widget);
 
@@ -1467,26 +1887,14 @@ rb_entry_view_constructor (GType type,
 					  G_CALLBACK (rb_entry_view_pixbuf_clicked_cb),
 					  view);
 
-		gtk_tooltips_set_tip (GTK_TOOLTIPS (tooltip), GTK_WIDGET (column->button),
-				       _("Now Playing"), NULL);
+		gtk_widget_set_tooltip_text (gtk_tree_view_column_get_widget (column),
+					     _("Now Playing"));
 	}
 
 	view->priv->gconf_notification_id =
 		eel_gconf_notification_add (CONF_UI_COLUMNS_SETUP,
 					    rb_entry_view_columns_config_changed_cb,
 					    view);
-	if (view->priv->sorting_key) {
-		view->priv->sorting_gconf_notification_id =
-			eel_gconf_notification_add (view->priv->sorting_key,
-						    rb_entry_view_sort_key_changed_cb,
-						    view);
-	}
-
-	if (view->priv->sorting_key) {
-		char *s = eel_gconf_get_string (view->priv->sorting_key);
-		rb_entry_view_set_sorting_type (view, s);
-		g_free (s);
-	}
 
 	{
 		RhythmDBQueryModel *query_model;
@@ -1494,8 +1902,6 @@ rb_entry_view_constructor (GType type,
 		rb_entry_view_set_model (view, RHYTHMDB_QUERY_MODEL (query_model));
 		g_object_unref (query_model);
 	}
-
-	return G_OBJECT (view);
 }
 
 static void
@@ -1600,6 +2006,15 @@ harvest_entries (GtkTreeModel *model,
 	return FALSE;
 }
 
+/**
+ * rb_entry_view_get_selected_entries:
+ * @view: a #RBEntryView
+ *
+ * Gathers the selected entries from the view.
+ *
+ * Return value: a #GList of selected entries in the view
+ *  (must be freed and the entries unreffed)
+ */
 GList *
 rb_entry_view_get_selected_entries (RBEntryView *view)
 {
@@ -1690,12 +2105,28 @@ rb_entry_view_selection_changed_cb (GtkTreeSelection *selection,
 		view->priv->selection_changed_id = g_idle_add ((GSourceFunc)rb_entry_view_emit_selection_changed, view);
 }
 
+/**
+ * rb_entry_view_have_selection:
+ * @view: a #RBEntryView
+ *
+ * Determines whether there is an active selection in the view.
+ *
+ * Return value: TRUE if one or more rows are selected
+ */
 gboolean
 rb_entry_view_have_selection (RBEntryView *view)
 {
 	return view->priv->have_selection;
 }
 
+/**
+ * rb_entry_view_have_complete_selection:
+ * @view: a #RBEntryView
+ *
+ * Determines whether all entries in the view are selected.
+ *
+ * Return value: TRUE if all rows in the view are selected
+ */
 gboolean
 rb_entry_view_have_complete_selection (RBEntryView *view)
 {
@@ -1800,18 +2231,38 @@ rb_entry_view_rows_reordered_cb (GtkTreeModel *model,
 	gtk_widget_queue_draw (GTK_WIDGET (view));
 }
 
+/**
+ * rb_entry_view_select_all:
+ * @view: a #RBEntryView
+ *
+ * Selects all rows in the view
+ */
 void
 rb_entry_view_select_all (RBEntryView *view)
 {
 	gtk_tree_selection_select_all (view->priv->selection);
 }
 
+/**
+ * rb_entry_view_select_none:
+ * @view: a #RBEntryView
+ *
+ * Deselects all rows in the view.
+ */
 void
 rb_entry_view_select_none (RBEntryView *view)
 {
 	gtk_tree_selection_unselect_all (view->priv->selection);
 }
 
+/**
+ * rb_entry_view_select_entry:
+ * @view: a #RBEntryView
+ * @entry: a #RhythmDBEntry to select
+ *
+ * If the specified entry is present in the view, it is added
+ * to the selection.
+ */
 void
 rb_entry_view_select_entry (RBEntryView *view,
 			    RhythmDBEntry *entry)
@@ -1829,6 +2280,14 @@ rb_entry_view_select_entry (RBEntryView *view,
 	}
 }
 
+/**
+ * rb_entry_view_scroll_to_entry:
+ * @view: a #RBEntryView
+ * @entry: a #RhythmDBEntry to scroll to
+ *
+ * If the specified entry is present in the view, the view will be
+ * scrolled so that the entry is visible.
+ */
 void
 rb_entry_view_scroll_to_entry (RBEntryView *view,
 			       RhythmDBEntry *entry)
@@ -1864,6 +2323,16 @@ rb_entry_view_scroll_to_iter (RBEntryView *view,
 	gtk_tree_path_free (path);
 }
 
+/**
+ * rb_entry_view_get_entry_visible:
+ * @view: a #RBEntryView
+ * @entry: a #RhythmDBEntry to check
+ *
+ * Determines whether a specified entry is present in the view
+ * and is currently visible.
+ *
+ * Return value: TRUE if the entry is visible
+ */
 gboolean
 rb_entry_view_get_entry_visible (RBEntryView *view,
 				 RhythmDBEntry *entry)
@@ -1879,6 +2348,15 @@ rb_entry_view_get_entry_visible (RBEntryView *view,
 	return realized && visible;
 }
 
+/**
+ * rb_entry_view_get_entry_contained:
+ * @view: a #RBEntryView
+ * @entry: a #RhythmDBEntry to check
+ *
+ * Determines whether a specified entry is present in the view.
+ *
+ * Return value: TRUE if the entry is present in the view
+ */
 gboolean
 rb_entry_view_get_entry_contained (RBEntryView *view,
 				   RhythmDBEntry *entry)
@@ -1924,6 +2402,15 @@ rb_entry_view_entry_is_visible (RBEntryView *view,
 	*visible = (rect.y != 0 && rect.height != 0);
 }
 
+/**
+ * rb_entry_view_enable_drag_source:
+ * @view: a #RBEntryView
+ * @targets: an array of #GtkTargetEntry structures defining the drag data targets
+ * @n_targets: the number of entries in the target array
+ *
+ * Enables the entry view to act as a data source for drag an drop operations,
+ * using a specified set of data targets.
+ */
 void
 rb_entry_view_enable_drag_source (RBEntryView *view,
 				 const GtkTargetEntry *targets,
@@ -2021,6 +2508,16 @@ rb_entry_view_sync_columns_visible (RBEntryView *view)
 	g_free (config);
 }
 
+/**
+ * rb_entry_view_set_state:
+ * @view: a #RBEntryView
+ * @state: the new playing entry state
+ *
+ * Sets the icon to be drawn in the 'playing' column next to the
+ * current playing entry.  RB_ENTRY_VIEW_PLAYING and RB_ENTRY_VIEW_PAUSED
+ * should be used when the source containing the entry view is playing,
+ * and RB_ENTRY_VIEW_NOT_PLAYING otherwise.
+ */
 void
 rb_entry_view_set_state (RBEntryView *view,
 			 RBEntryViewState state)
@@ -2055,6 +2552,17 @@ rb_entry_view_emit_row_changed (RBEntryView *view,
 	return TRUE;
 }
 
+/**
+ * rb_entry_view_set_fixed_column_width:
+ * @view: a #RBEntryView
+ * @column: the column to set the width for
+ * @renderer: a temporary cell renderer to use
+ * @strings: a NULL-terminated array of strings that will be displayed in the column
+ *
+ * Helper function for calling @rb_set_tree_view_column_fixed_width on
+ * a column.  This is important for performance reasons, as having the
+ * tree view measure the strings in each of 20000 rows is very slow.
+ */
 void
 rb_entry_view_set_fixed_column_width (RBEntryView *view,
 				      GtkTreeViewColumn *column,
@@ -2068,22 +2576,19 @@ rb_entry_view_set_fixed_column_width (RBEntryView *view,
 					     5);
 }
 
+/**
+ * rb_entry_view_get_time_date_column_sample:
+ *
+ * Returns a sample string for use in columns displaying times
+ * and dates in 'friendly' form (see @rb_utf_friendly_time).
+ * For use with @rb_entry_view_set_fixed_column_width.
+ *
+ * Return value: sample date string
+ */
 const char *
 rb_entry_view_get_time_date_column_sample ()
 {
 	static const char *sample = NULL;
-	/*
-	 * Currently, Japanese is the only translation that uses
-	 * anything other than %Y, %m ,%d, %H, and %M to format dates.
-	 * It uses %B (month name) and %e (days), and the values for
-	 * the month name appear to all consist of the month number
-	 * followed by a single character, so they're of consistent
-	 * width.  So, this approach should work for every locale.
-	 *
-	 * Midnight on September 30th, 2000 is the widest date/time I
-	 * can think of.  2000-09-30 00:00.
-	 */
-
 	if (sample == NULL) {
  		time_t then;
 
@@ -2096,6 +2601,13 @@ rb_entry_view_get_time_date_column_sample ()
 	return sample;
 }
 
+/**
+ * rb_entry_view_resort_model:
+ * @view: a #RBEntryView to resort
+ *
+ * Resorts the entries in the entry view.  Mostly to be used
+ * when a new model is associated with the view.
+ */
 void
 rb_entry_view_resort_model (RBEntryView *view)
 {
@@ -2109,10 +2621,36 @@ rb_entry_view_resort_model (RBEntryView *view)
 	rhythmdb_query_model_set_sort_order (view->priv->model,
 					     sort_data->func,
 					     sort_data->data,
-					     sort_data->data_destroy,
+					     NULL,
 					     (view->priv->sorting_order == GTK_SORT_DESCENDING));
 }
 
+/**
+ * rb_entry_view_set_column_editable:
+ * @view: a #RBEntryView
+ * @column: a #RBEntryViewColumn to update
+ * @editable: %TRUE to make the column editable, %FALSE otherwise
+ *
+ * Enables in-place editing of the values in a column.
+ * The underlying %RhythmDBEntry is updated when editing is complete.
+ */
+void
+rb_entry_view_set_column_editable (RBEntryView *view,
+				   RBEntryViewColumn column_type,
+				   gboolean editable)
+{
+	GtkTreeViewColumn *column;
+	GList *renderers;
+
+	column = rb_entry_view_get_column (view, column_type);
+	if (column == NULL)
+		return;
+
+	renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (column));
+	g_object_set (renderers->data, "editable", editable, NULL);
+	g_list_free (renderers);
+}
+
 /* This should really be standard. */
 #define ENUM_ENTRY(NAME, DESC) { NAME, "" #NAME "", DESC }
 
