@@ -1,6 +1,4 @@
 /*
- *  arch-tag: Header for main song information display widget
- *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003 Colin Walters <walters@verbum.org>
  *
@@ -74,8 +72,6 @@ void		rb_header_sync			(RBHeader *header);
 
 void		rb_header_sync_time		(RBHeader *header);
 
-char *		rb_header_get_elapsed_string	(RBHeader *header);
-
 G_END_DECLS
 
 #endif /* __RB_HEADER_H */
