@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of library browser widget
  *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003,2004 Colin Walters <walters@verbum.org>
@@ -37,6 +35,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
+#include "gseal-gtk-compat.h"
 #include "rb-library-browser.h"
 #include "rb-preferences.h"
 #include "eel-gconf-extensions.h"
@@ -50,8 +49,7 @@ static void rb_library_browser_class_init (RBLibraryBrowserClass *klass);
 static void rb_library_browser_init (RBLibraryBrowser *entry);
 static void rb_library_browser_finalize (GObject *object);
 static void rb_library_browser_dispose (GObject *object);
-static GObject* rb_library_browser_constructor (GType type, guint n_construct_properties,
-						GObjectConstructParam *construct_properties);
+static void rb_library_browser_constructed (GObject *object);
 static void rb_library_browser_set_property (GObject *object,
 					     guint prop_id,
 					     const GValue *value,
@@ -152,7 +150,7 @@ rb_library_browser_class_init (RBLibraryBrowserClass *klass)
 
 	object_class->finalize = rb_library_browser_finalize;
 	object_class->dispose = rb_library_browser_dispose;
-	object_class->constructor = rb_library_browser_constructor;
+	object_class->constructed = rb_library_browser_constructed;
 	object_class->set_property = rb_library_browser_set_property;
 	object_class->get_property = rb_library_browser_get_property;
 
@@ -229,20 +227,16 @@ rb_library_browser_init (RBLibraryBrowser *widget)
 	priv->selections = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, (GDestroyNotify)rb_list_deep_free);
 }
 
-static GObject *
-rb_library_browser_constructor (GType type,
-				guint n_construct_properties,
-				GObjectConstructParam *construct_properties)
+static void
+rb_library_browser_constructed (GObject *object)
 {
-	RBLibraryBrowserClass *klass;
 	RBLibraryBrowser *browser;
 	RBLibraryBrowserPrivate *priv;
 	int i;
 
-	klass = RB_LIBRARY_BROWSER_CLASS (g_type_class_peek (RB_TYPE_LIBRARY_BROWSER));
+	RB_CHAIN_GOBJECT_METHOD (rb_library_browser_parent_class, constructed, object);
 
-	browser = RB_LIBRARY_BROWSER (G_OBJECT_CLASS (rb_library_browser_parent_class)->
-			constructor (type, n_construct_properties, construct_properties));
+	browser = RB_LIBRARY_BROWSER (object);
 	priv = RB_LIBRARY_BROWSER_GET_PRIVATE (browser);
 
 	for (i = 0; i < num_browser_properties; i++) {
@@ -271,8 +265,6 @@ rb_library_browser_constructor (GType type,
 	priv->browser_view_notify_id =
 		eel_gconf_notification_add (CONF_UI_BROWSER_VIEWS,
 				(GConfClientNotifyFunc) rb_library_browser_views_changed, browser);
-
-	return G_OBJECT (browser);
 }
 
 static void
@@ -383,6 +375,8 @@ rb_library_browser_get_property (GObject *object,
  * @db: the #RhythmDB instance
  * @entry_type: the entry type to use in the browser
  *
+ * Creates a new library browser.
+ *
  * Return value: a new RBLibraryBrowser
  */
 RBLibraryBrowser *
@@ -406,7 +400,7 @@ update_browser_property_visibilty (RhythmDBPropType prop,
 {
 	gboolean old_vis, new_vis;
 
-	old_vis = GTK_WIDGET_VISIBLE (view);
+	old_vis = gtk_widget_get_visible (GTK_WIDGET (view));
 	new_vis = (g_list_find (properties, (gpointer)prop) != NULL);
 
 	if (old_vis != new_vis) {
@@ -545,6 +539,8 @@ rb_library_browser_construct_query (RBLibraryBrowser *widget)
  * rb_library_browser_has_selection:
  * @widget: a #RBLibraryBrowser
  *
+ * Determines whether the browser has an active selection.
+ *
  * Return value: TRUE if any items in the browser are selected.
  */
 gboolean
@@ -816,7 +812,9 @@ rb_library_browser_set_selection (RBLibraryBrowser *widget,
  * rb_library_browser_get_property_views:
  * @widget: a #RBLibraryBrowser
  *
- * Return value: a GList containing the #RBPropertyView<!-- -->s
+ * Retrieves the property view widgets from the browser.
+ *
+ * Return value: a GList containing the #RBPropertyView widgets
  *  in the browser.
  */
 GList*
@@ -832,8 +830,10 @@ rb_library_browser_get_property_views (RBLibraryBrowser *widget)
  * @widget: a #RBLibraryBrowser
  * @type: the property
  *
- * Return value: the #RBPropertyView for the specified property, or
- *  NULL if there isn't one
+ * Retrieves the property view widget for the specified property,
+ * if there is one.
+ *
+ * Return value: #RBPropertyView widget, or NULL
  */
 RBPropertyView *
 rb_library_browser_get_property_view (RBLibraryBrowser *widget,
