@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of search entry widget
  *
  *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
  *  Copyright (C) 2003 Colin Walters <walters@verbum.org>
@@ -36,10 +34,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#if !GTK_CHECK_VERSION(2,16,0)
-#include "libsexy/sexy-icon-entry.h"
-#endif
-
 #include "rb-search-entry.h"
 
 static void rb_search_entry_class_init (RBSearchEntryClass *klass);
@@ -53,12 +47,10 @@ static void rb_search_entry_activate_cb (GtkEntry *gtkentry,
 static gboolean rb_search_entry_focus_out_event_cb (GtkWidget *widget,
 				                    GdkEventFocus *event,
 				                    RBSearchEntry *entry);
-#if GTK_CHECK_VERSION(2,16,0)
 static void rb_search_entry_clear_cb (GtkEntry *entry,
 				      GtkEntryIconPosition icon_pos,
 				      GdkEvent *event,
 				      RBSearchEntry *search_entry);
-#endif
 
 struct RBSearchEntryPrivate
 {
@@ -166,7 +158,6 @@ rb_search_entry_init (RBSearchEntry *entry)
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
 	gtk_box_pack_start (GTK_BOX (entry), label, FALSE, TRUE, 0);
 
-#if GTK_CHECK_VERSION(2,16,0)
 	entry->priv->entry = gtk_entry_new ();
 	gtk_entry_set_icon_from_stock (GTK_ENTRY (entry->priv->entry),
 				       GTK_ENTRY_ICON_SECONDARY,
@@ -178,10 +169,6 @@ rb_search_entry_init (RBSearchEntry *entry)
 				 "icon-press",
 				 G_CALLBACK (rb_search_entry_clear_cb),
 				 entry, 0);
-#else
-	entry->priv->entry = sexy_icon_entry_new ();
-	sexy_icon_entry_add_clear_button (SEXY_ICON_ENTRY (entry->priv->entry));
-#endif
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label),
 				       entry->priv->entry);
@@ -220,6 +207,8 @@ rb_search_entry_finalize (GObject *object)
 /**
  * rb_search_entry_new:
  *
+ * Creates a new search entry widget.
+ *
  * Return value: new search entry widget.
  */
 RBSearchEntry *
@@ -353,7 +342,9 @@ rb_search_entry_focus_out_event_cb (GtkWidget *widget,
  * rb_search_entry_searching:
  * @entry: a #RBSearchEntry
  *
- * Return value: TRUE if there is search text
+ * Returns %TRUE if there is search text in the entry widget.
+ *
+ * Return value: %TRUE if searching
  */
 gboolean
 rb_search_entry_searching (RBSearchEntry *entry)
@@ -381,7 +372,6 @@ rb_search_entry_grab_focus (RBSearchEntry *entry)
 	gtk_widget_grab_focus (GTK_WIDGET (entry->priv->entry));
 }
 
-#if GTK_CHECK_VERSION(2,16,0)
 static void
 rb_search_entry_clear_cb (GtkEntry *entry,
 			  GtkEntryIconPosition icon_pos,
@@ -390,4 +380,3 @@ rb_search_entry_clear_cb (GtkEntry *entry,
 {
 	rb_search_entry_set_text (search_entry, "");
 }
-#endif
