@@ -1,6 +1,4 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- *  arch-tag: Implementation of new station dialog
  *
  *  Copyright (C) 2005 Renato Araujo Oliveira Filho - INdT <renato.filho@indt.org.br>
  *
@@ -136,6 +134,7 @@ rb_uri_dialog_class_init (RBURIDialogClass *klass)
 static void
 rb_uri_dialog_init (RBURIDialog *dialog)
 {
+	GtkWidget  *content_area;
 	GtkBuilder *builder;
 
 	/* create the dialog and some buttons forward - close */
@@ -146,9 +145,11 @@ rb_uri_dialog_init (RBURIDialog *dialog)
 				 G_CALLBACK (rb_uri_dialog_response_cb),
 				 dialog, 0);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 
 	dialog->priv->cancelbutton = gtk_dialog_add_button (GTK_DIALOG (dialog),
 							    GTK_STOCK_CANCEL,
@@ -160,7 +161,7 @@ rb_uri_dialog_init (RBURIDialog *dialog)
 
 	builder = rb_builder_load ("uri-new.ui", dialog);
 
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox),
+	gtk_container_add (GTK_CONTAINER (content_area),
 			   GTK_WIDGET (gtk_builder_get_object (builder, "newuri")));
 
 	/* get the widgets from the GtkBuilder */
